@@ -2,7 +2,8 @@
 
 from acp.client import DefaultACPClient, ClientSideConnection
 from acp.agent import AgentSideConnection
-from acp.core import create_session_model_state
+from acp.debug_server import cli
+from acp.filesystem import ACPFileSystem, ACPPath
 from acp.agent.protocol import (
     Agent,
     AgentExtensibilityCapability,
@@ -54,10 +55,12 @@ from acp.schema import (
     WaitForTerminalExitResponse,
     WriteTextFileRequest,
     WriteTextFileResponse,
+    PROTOCOL_VERSION,
+    AgentMethod,
+    ClientMethod,
 )
 from acp.stdio import stdio_streams
 from acp.exceptions import RequestError
-from acp.meta import PROTOCOL_VERSION, AgentMethod, ClientMethod
 
 __version__ = "0.0.1"
 
@@ -122,8 +125,11 @@ __all__ = [  # noqa: RUF022
     "FileSystemCapability",
     "TerminalCapability",
     "ExtensibilityCapability",
-    # utilities
-    "create_session_model_state",
     # stdio helper
     "stdio_streams",
+    # filesystem
+    "ACPFileSystem",
+    "ACPPath",
+    # cli
+    "cli",
 ]
