@@ -3,7 +3,7 @@
 from __future__ import annotations
 
 import asyncio
-from collections.abc import Callable, Coroutine
+from collections.abc import Awaitable, Callable, Coroutine
 import contextlib
 import copy
 from dataclasses import dataclass
@@ -33,14 +33,12 @@ from acp.task import (
 from llmling_agent import log
 
 
-logger = log.get_logger(__name__)
-
 if TYPE_CHECKING:
-    from acp.acp_types import JsonValue, MethodHandler
-    from acp.task import SenderFactory
+    from acp.task.sender import SenderFactory
 
-__all__ = ["Connection"]
 
+JsonValue = Any
+MethodHandler = Callable[[str, JsonValue | None, bool], Awaitable[JsonValue | None]]
 
 DispatcherFactory = Callable[
     [MessageQueue, TaskSupervisor, MessageStateStore, RequestRunner, NotificationRunner],
@@ -48,6 +46,9 @@ DispatcherFactory = Callable[
 ]
 
 
+logger = log.get_logger(__name__)
+
+
 class StreamDirection(str, Enum):
     """Stream direction."""
 
@@ -57,6 +58,8 @@ class StreamDirection(str, Enum):
 
 @dataclass(frozen=True, slots=True)
 class StreamEvent:
+    """Stream event."""
+
     direction: StreamDirection
     message: dict[str, Any]
 
@@ -150,11 +153,13 @@ class Connection:
                 line = await self._reader.readline()
                 if not line:
                     break
+                if line == b"null\n":
+                    continue
                 try:
                     message = anyenv.load_json(line, return_type=dict)
                 except Exception:
                     # Align with Rust/TS: on parse error, just skip instead of response
-                    logger.exception("Error parsing JSON-RPC message")
+                    logger.exception("Error parsing JSON-RPC message", line=line)
                     continue
                 else:
                     self._notify_observers(StreamDirection.INCOMING, message)
