@@ -6,15 +6,12 @@ from llmling.cli.utils import get_command_help
 import typer as t
 
 from llmling_agent_cli.agent import add_agent_file, list_agents, set_active_file
-from llmling_agent_cli.chat import chat_command
 from llmling_agent_cli.history import history_cli
-from llmling_agent_cli.quickstart import quickstart_command
 from llmling_agent_cli.run import run_command
 from llmling_agent_cli.serve_acp import acp_command
 from llmling_agent_cli.serve_api import api_command
 from llmling_agent_cli.serve_mcp import serve_command
 from llmling_agent_cli.task import task_command
-from llmling_agent_cli.ui import ui_command
 from llmling_agent_cli.watch import watch_command
 
 
@@ -28,13 +25,10 @@ cli.command(name="add")(add_agent_file)
 cli.command(name="run")(run_command)
 cli.command(name="list")(list_agents)
 cli.command(name="set")(set_active_file)
-cli.command(name="chat")(chat_command)
-cli.command(name="quickstart")(quickstart_command)
 cli.command(name="watch")(watch_command)
 cli.command(name="serve-acp")(acp_command)
 cli.command(name="serve-mcp")(serve_command)
 cli.command(name="serve-api")(api_command)
 cli.command(name="task")(task_command)
-cli.command(name="ui")(ui_command)
 
 cli.add_typer(history_cli, name="history")
