@@ -12,27 +12,8 @@ import llmling_agent_config
 
 if TYPE_CHECKING:
     from llmling_agent.agent.agent import AgentType
-    from llmling_agent.agent.structured import StructuredAgent
 
 
-EXAMPLE = """
-# Example agent with team
-agents:
-  analyzer:
-    name: "Analyzer"
-    model: "gpt-5"
-    capabilities:
-      can_load_resources: true
-
-teams:
-  analysis_team:
-    mode: "sequential"
-    members: ["analyzer"]
-    connections:
-      - target: "output_handler"
-        type: "forward"
-"""
-
 SYS_PROMPT = """
 You are an expert at creating LLMling-agent configurations.
 Generate complete, valid YAML that CAN include:
@@ -53,19 +34,20 @@ README_URL = "https://raw.githubusercontent.com/phil65/llmling-agent/main/README
 
 async def create_architect_agent(
     name: str = "config_generator",
-    model: str = "openrouter:o3-mini",
+    model: str = "openrouter:gpt-5-nano",
     provider: AgentType = "pydantic_ai",
-) -> StructuredAgent[None, YAMLCode]:
+) -> Agent[None, YAMLCode]:
     code = await read_folder_as_text(CONFIG_PATH, pattern="**/*.py")
     core_code = await read_folder_as_text(CORE_CONFIG_PATH, pattern="**/*.py")
     readme = await read_path(README_URL)
-    context = f"Code:\n{core_code}\n{code}\n\nExample:\n{EXAMPLE}\n\\Readme:\n{readme}"
-    agent = Agent[None](
+    context = f"Code:\n{core_code}\n{code}\nReadme:\n{readme}"
+    agent = Agent(
         name,
         model=model,
         provider=provider,
         system_prompt=SYS_PROMPT,
-    ).to_structured(YAMLCode)
+        output_type=YAMLCode,
+    )
     agent.conversation.add_context_message(context)
     return agent
 
