@@ -29,9 +29,10 @@ if TYPE_CHECKING:
     from llmling.config.models import Resource
     from llmling.prompts import PromptType
     from toprompt import AnyPromptType
+    from upath.types import JoinablePathLike
 
     from llmling_agent.agent.agent import Agent
-    from llmling_agent.common_types import MessageRole, SessionIdType, StrPath
+    from llmling_agent.common_types import MessageRole, SessionIdType
     from llmling_agent_config.session import MemoryConfig
 
 logger = get_logger(__name__)
@@ -64,7 +65,7 @@ class ConversationManager:
 
     def __init__(
         self,
-        agent: Agent[Any],
+        agent: Agent[Any, Any],
         session_config: MemoryConfig | None = None,
         *,
         resources: Sequence[Resource | PromptType | str] = (),
@@ -87,7 +88,7 @@ class ConversationManager:
 
         if session_config is not None and session_config.session is not None:
             storage = self._agent.context.storage
-            self._current_history = storage.filter_messages_sync(session_config.session)
+            self._current_history = storage.filter_messages.sync(session_config.session)
             if session_config.session.name:
                 self.id = session_config.session.name
 
@@ -153,7 +154,7 @@ class ConversationManager:
                 return list(self.chat_messages[key])
             case str():
                 query = SessionQuery(name=key)
-                return self._agent.context.storage.filter_messages_sync(query=query)
+                return self._agent.context.storage.filter_messages.sync(query=query)
             case _:
                 msg = f"Invalid key type: {type(key)}"
                 raise TypeError(msg)
@@ -292,7 +293,7 @@ class ConversationManager:
                 msg = f"Invalid type for session: {type(session)}"
                 raise ValueError(msg)
         self.chat_messages.clear()
-        self.chat_messages.extend(storage.filter_messages_sync(query))
+        self.chat_messages.extend(storage.filter_messages.sync(query))
 
     def get_history(
         self,
@@ -427,11 +428,11 @@ class ConversationManager:
         header = f"Content from {source}:" if source else "Additional context:"
         formatted = f"{header}{meta_str}\n{content}\n"
 
-        chat_message = ChatMessage[str](
+        chat_message = ChatMessage(
             content=formatted,
             role="user",
             name="user",
-            model=self._agent.model_name,
+            model_name=self._agent.model_name,
             metadata=metadata,
             conversation_id="context",  # TODO: should probably allow DB field to be NULL
         )
@@ -441,7 +442,7 @@ class ConversationManager:
 
     async def add_context_from_path(
         self,
-        path: StrPath,
+        path: JoinablePathLike,
         *,
         convert_to_md: bool = False,
         **metadata: Any,
@@ -535,7 +536,7 @@ if __name__ == "__main__":
     from llmling_agent import Agent
 
     async def main():
-        async with Agent[None]() as agent:
+        async with Agent() as agent:
             await agent.conversation.add_context_from_path("E:/mcp_zed.yml")
             print(agent.conversation.get_history())
 
