@@ -5,7 +5,7 @@ from __future__ import annotations
 from collections.abc import Callable, Mapping
 from typing import TYPE_CHECKING, Any, Literal, cast, overload
 
-from schemez import Schema
+from schemez import Schema, create_constructor_schema
 
 from llmling_agent.log import get_logger
 from llmling_agent.messaging.messages import ChatMessage
@@ -18,7 +18,7 @@ if TYPE_CHECKING:
     from toprompt import AnyPromptType
 
     from llmling_agent import AgentPool, MessageNode
-    from llmling_agent.agent import AnyAgent
+    from llmling_agent.agent import Agent
     from llmling_agent.delegation.base_team import BaseTeam
 
 
@@ -87,7 +87,7 @@ def get_label(item: Any) -> str:
 class Interactions[TDeps, TResult]:
     """Manages agent communication patterns."""
 
-    def __init__(self, agent: AnyAgent[TDeps, TResult]):
+    def __init__(self, agent: Agent[TDeps, TResult]):
         self.agent = agent
 
     async def conversation(
@@ -167,7 +167,7 @@ class Interactions[TDeps, TResult]:
         selections: AgentPool,
         task: str,
         prompt: AnyPromptType | None = None,
-    ) -> Pick[AnyAgent[Any, Any]]: ...
+    ) -> Pick[Agent[Any, Any]]: ...
 
     @overload
     async def pick(
@@ -240,7 +240,7 @@ Available options:
 Select ONE option by its exact label."""
 
         # Get LLM's string-based decision
-        result = await self.agent.to_structured(LLMPick).run(prompt or default_prompt)
+        result = await self.agent.run(prompt or default_prompt, output_type=LLMPick)
 
         # Convert to type-safe decision
         if result.content.selection not in label_map:
@@ -292,7 +292,7 @@ Select ONE option by its exact label."""
         min_picks: int = 1,
         max_picks: int | None = None,
         prompt: AnyPromptType | None = None,
-    ) -> MultiPick[AnyAgent[Any, Any]]: ...
+    ) -> MultiPick[Agent[Any, Any]]: ...
 
     async def pick_multiple[T](
         self,
@@ -360,9 +360,7 @@ Available options:
 {picks_info} options by their exact labels.
 List your selections, one per line, followed by your reasoning."""
 
-        result = await self.agent.to_structured(LLMMultiPick).run(
-            prompt or default_prompt
-        )
+        result = await self.agent.run(prompt or default_prompt, output_type=LLMMultiPick)
 
         # Validate selections
         invalid = [s for s in result.content.selections if s not in label_map]
@@ -401,8 +399,6 @@ List your selections, one per line, followed by your reasoning."""
             prompt: Optional custom prompt
             include_tools: Whether to include other tools (tool_calls mode only)
         """
-        from schemez import create_constructor_schema
-
         # Create model for single instance
         item_model = Schema.for_class_ctor(as_type)
 
@@ -417,7 +413,7 @@ List your selections, one per line, followed by your reasoning."""
                 instance: item_model  # type: ignore
                 # explanation: str | None = None
 
-            result = await self.agent.to_structured(Extraction).run(final_prompt)
+            result = await self.agent.run(final_prompt, output_type=Extraction)
 
             # Convert model instance to actual type
             return as_type(**result.content.instance.model_dump())  # type: ignore
@@ -428,15 +424,14 @@ List your selections, one per line, followed by your reasoning."""
             """Construct instance from extracted data."""
             return as_type(**kwargs)
 
-        structured = self.agent.to_structured(item_model)
         tool = Tool.from_callable(
             construct,
             name_override=schema["name"],
             description_override=schema["description"],
             # schema_override=schema,
         )
-        with structured.tools.temporary_tools(tool, exclusive=not include_tools):
-            result = await structured.run(final_prompt)  # type: ignore
+        with self.agent.tools.temporary_tools(tool, exclusive=not include_tools):
+            result = await self.agent.run(final_prompt, output_type=item_model)  # type: ignore
         return result.content  # type: ignore
 
     async def extract_multiple[T](
@@ -463,8 +458,6 @@ List your selections, one per line, followed by your reasoning."""
             prompt: Optional custom prompt
             include_tools: Whether to include other tools (tool_calls mode only)
         """
-        from schemez import create_constructor_schema
-
         item_model = Schema.for_class_ctor(as_type)
 
         instances: list[T] = []
@@ -484,7 +477,7 @@ List your selections, one per line, followed by your reasoning."""
                 instances: list[item_model]  # type: ignore
                 # explanation: str | None = None
 
-            result = await self.agent.to_structured(Extraction).run(final_prompt)
+            result = await self.agent.run(final_prompt, output_type=Extraction)
 
             # Validate counts
             num_instances = len(result.content.instances)
@@ -519,10 +512,12 @@ List your selections, one per line, followed by your reasoning."""
 
         add_instance.__annotations__ = schema_obj.get_annotations()
         add_instance.__signature__ = schema_obj.to_python_signature()  # type: ignore
-        structured = self.agent.to_structured(item_model)
-        with structured.tools.temporary_tools(add_instance, exclusive=not include_tools):
-            # Create extraction prompt
-            await structured.run(final_prompt)
+        async with self.agent.temporary_state(
+            tools=[add_instance],
+            replace_tools=not include_tools,
+            output_type=item_model,
+        ):
+            await self.agent.run(final_prompt)  # Create extraction prompt
 
         if len(instances) < min_items:
             msg = f"Found only {len(instances)} instances, need at least {min_items}"
