@@ -3,29 +3,13 @@
 from __future__ import annotations
 
 from collections.abc import Awaitable, Callable
-import os
-from typing import (
-    Any,
-    ClassVar,
-    Literal,
-    Protocol,
-    get_args,
-    get_origin,
-    runtime_checkable,
-)
+from typing import Any, ClassVar, Literal, get_args, get_origin
 from uuid import UUID
 
 from llmling import LLMCallableTool
 from pydantic import BaseModel, ConfigDict, field_validator
-from upath.types import JoinablePathLike
-
-
-@runtime_checkable
-class ModelProtocol(Protocol):
-    """Protocol for model objects."""
-
-    @property
-    def model_name(self) -> str: ...
+from pydantic_ai import AgentStreamEvent, RunContext
+from pydantic_ai.models import Model
 
 
 # Define what we consider JSON-serializable
@@ -38,7 +22,6 @@ type JsonArray = list[JsonValue]
 SimpleJsonType = dict[
     str, bool | int | float | str | list[str] | dict[str, bool | int | float | str]
 ]
-type StrPath = JoinablePathLike | os.PathLike
 type SessionIdType = str | UUID | None
 
 
@@ -47,7 +30,7 @@ TeamName = str
 AgentName = str
 MessageRole = Literal["user", "assistant", "system"]
 PartType = Literal["text", "image", "audio", "video"]
-ModelType = ModelProtocol | str | None
+ModelType = Model | str | None
 EnvironmentType = Literal["file", "inline"]
 ToolSource = Literal["runtime", "agent", "builtin", "dynamic", "task", "mcp", "toolset"]
 AnyCallable = Callable[..., Any]
@@ -59,6 +42,10 @@ type OptionalAwaitable[T] = T | Awaitable[T]
 
 type ToolType = str | AnyCallable | LLMCallableTool
 
+# Event handler types for composable event processing
+# Individual event handler for composability - takes single events
+IndividualEventHandler = Callable[[RunContext, AgentStreamEvent], Awaitable[None]]
+
 # P = ParamSpec("P")
 # SyncAsync = Callable[P, OptionalAwaitable[T]]
 EndStrategy = Literal["early", "exhaustive"]
