@@ -16,7 +16,6 @@ from llmling_agent.messaging.messagenode import MessageNode
 from llmling_agent.models.manifest import AgentsManifest
 from llmling_agent.talk.stats import AggregatedMessageStats
 from llmling_agent.tools.base import Tool
-from llmling_agent.utils.inspection import has_return_type
 from llmling_agent_config.teams import TeamConfig
 
 
@@ -28,7 +27,7 @@ if TYPE_CHECKING:
     from psygnal.containers._evented_list import ListEvents
     from toprompt import AnyPromptType
 
-    from llmling_agent import AgentPool, AnyAgent, Team
+    from llmling_agent import Agent, AgentPool, Team
     from llmling_agent.common_types import ModelType, ToolType
     from llmling_agent.delegation.teamrun import ExtendedTeamTalk, TeamRun
     from llmling_agent.messaging.messages import ChatMessage, TeamResponse
@@ -83,7 +82,7 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
         description: str | None = None,
         shared_prompt: str | None = None,
         mcp_servers: list[str | MCPServerConfig] | None = None,
-        picker: AnyAgent[Any, Any] | None = None,
+        picker: Agent[Any, Any] | None = None,
         num_picks: int | None = None,
         pick_prompt: str | None = None,
     ):
@@ -142,14 +141,14 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
             if self.num_picks == 1:
                 result = await self.picker.talk.pick(self, task, self.pick_prompt)
                 return [result.selection]
-            result = await self.picker.talk.pick_multiple(
+            multi_result = await self.picker.talk.pick_multiple(
                 self,
                 task,
                 min_picks=self.num_picks or 1,
                 max_picks=self.num_picks,
                 prompt=self.pick_prompt,
             )
-            return result.selections
+            return multi_result.selections
         return list(self.agents)
 
     def _on_node_changed(self, index: int, old: MessageNode, new: MessageNode):
@@ -159,9 +158,9 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
 
     def _on_node_added(self, index: int, node: MessageNode[Any, Any]):
         """Handler for adding nodes to the team."""
-        from llmling_agent.agent import Agent, StructuredAgent
+        from llmling_agent.agent import Agent
 
-        if isinstance(node, Agent | StructuredAgent):
+        if isinstance(node, Agent):
             node.tools.add_provider(self.mcp)
         # TODO: Right now connecting here is not desired since emission means db logging
         # ideally db logging would not rely on the "public" agent signal.
@@ -170,9 +169,9 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
 
     def _on_node_removed(self, index: int, node: MessageNode[Any, Any]):
         """Handler for removing nodes from the team."""
-        from llmling_agent.agent import Agent, StructuredAgent
+        from llmling_agent.agent import Agent
 
-        if isinstance(node, Agent | StructuredAgent):
+        if isinstance(node, Agent):
             node.tools.remove_provider(self.mcp)
         # node.tool_used.disconnect(self.tool_used)
 
@@ -198,18 +197,15 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
 
     def __or__(
         self,
-        other: AnyAgent[Any, Any] | ProcessorCallback[Any] | BaseTeam[Any, Any],
+        other: Agent[Any, Any] | ProcessorCallback[Any] | BaseTeam[Any, Any],
     ) -> TeamRun[Any, Any]:
         """Create a sequential pipeline."""
-        from llmling_agent.agent import Agent, StructuredAgent
+        from llmling_agent.agent import Agent
         from llmling_agent.delegation.teamrun import TeamRun
 
         # Handle conversion of callables first
         if callable(other):
-            if has_return_type(other, str):
-                other = Agent.from_callback(other)
-            else:
-                other = StructuredAgent.from_callback(other)
+            other = Agent.from_callback(other)
             other.context.pool = self.context.pool
 
         # If we're already a TeamRun, extend it
@@ -232,23 +228,20 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
     def __and__(self, other: Team[Any]) -> Team[Any]: ...
 
     @overload
-    def __and__(self, other: AnyAgent[TDeps, Any]) -> Team[TDeps]: ...
+    def __and__(self, other: Agent[TDeps, Any]) -> Team[TDeps]: ...
 
     @overload
-    def __and__(self, other: AnyAgent[Any, Any]) -> Team[Any]: ...
+    def __and__(self, other: Agent[Any, Any]) -> Team[Any]: ...
 
     def __and__(
-        self, other: Team[Any] | AnyAgent[Any, Any] | ProcessorCallback[Any]
+        self, other: Team[Any] | Agent[Any, Any] | ProcessorCallback[Any]
     ) -> Team[Any]:
         """Combine teams, preserving type safety for same types."""
-        from llmling_agent.agent import Agent, StructuredAgent
+        from llmling_agent.agent import Agent
         from llmling_agent.delegation.team import Team
 
         if callable(other):
-            if has_return_type(other, str):
-                other = Agent.from_callback(other)
-            else:
-                other = StructuredAgent.from_callback(other)
+            other = Agent.from_callback(other)
             other.context.pool = self.context.pool
 
         match other:
@@ -259,10 +252,10 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
                 # Everything else just becomes a member
                 return Team([*self.agents, other])
 
-    @property
-    def stats(self) -> AggregatedMessageStats:
+    async def get_stats(self) -> AggregatedMessageStats:
         """Get aggregated stats from all team members."""
-        return AggregatedMessageStats(stats=[agent.stats for agent in self.agents])
+        stats = [await agent.get_stats() for agent in self.agents]
+        return AggregatedMessageStats(stats=stats)
 
     @property
     def is_running(self) -> bool:
@@ -380,15 +373,15 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
 
         return "\n".join(lines)
 
-    def iter_agents(self) -> Iterator[AnyAgent[Any, Any]]:
+    def iter_agents(self) -> Iterator[Agent[Any, Any]]:
         """Recursively iterate over all child agents."""
-        from llmling_agent.agent import Agent, StructuredAgent
+        from llmling_agent.agent import Agent
 
         for node in self.agents:
             match node:
                 case BaseTeam():
                     yield from node.iter_agents()
-                case Agent() | StructuredAgent():
+                case Agent():
                     yield node
                 case _:
                     msg = f"Invalid node type: {type(node)}"
@@ -419,7 +412,7 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
             mode = "parallel" if isinstance(self, Team) else "sequential"
             team_config = TeamConfig(name=self.name, mode=mode, members=[])
         if not pool_ids:
-            logger.info("No pool found for team %s.", self.name)
+            logger.debug("No pool found for team %s.", self.name)
             return TeamContext(
                 node_name=self.name,
                 pool=shared_pool,
@@ -553,8 +546,8 @@ if __name__ == "__main__":
     async def main():
         from llmling_agent import Agent, Team
 
-        agent = Agent[None]("My Agent")
-        agent_2 = Agent[None]("My Agent")
+        agent = Agent("My Agent")
+        agent_2 = Agent("My Agent")
         team = Team([agent, agent_2], mcp_servers=["uvx mcp-server-git"])
         async with team:
             print(await agent.tools.get_tools())
