@@ -7,14 +7,17 @@ from contextlib import AsyncExitStack, asynccontextmanager, suppress
 import os
 from typing import TYPE_CHECKING, Any, Self, TypeVar, Unpack, cast, overload
 
+from anyenv import MultiEventHandler
 from llmling import BaseRegistry, LLMLingError
+from upath import UPath
 
-from llmling_agent.agent import Agent, StructuredAgent
+from llmling_agent.agent import Agent
 from llmling_agent.common_types import NodeName
 from llmling_agent.delegation.message_flow_tracker import MessageFlowTracker
 from llmling_agent.delegation.team import Team
 from llmling_agent.delegation.teamrun import TeamRun
 from llmling_agent.log import get_logger
+from llmling_agent.messaging.context import ProgressCallback
 from llmling_agent.messaging.messageemitter import MessageEmitter
 from llmling_agent.talk import Talk, TeamTalk
 from llmling_agent.talk.registry import ConnectionRegistry
@@ -33,16 +36,16 @@ if TYPE_CHECKING:
     from types import TracebackType
 
     from psygnal.containers._evented_dict import DictEvents
+    from pydantic_ai.output import OutputSpec
+    from upath.types import JoinablePathLike
 
-    from llmling_agent.agent import AnyAgent
     from llmling_agent.agent.agent import AgentKwargs
-    from llmling_agent.common_types import AgentName, SessionIdType, StrPath
+    from llmling_agent.common_types import AgentName, SessionIdType
     from llmling_agent.delegation.base_team import BaseTeam
-    from llmling_agent.messaging.context import ProgressCallback
     from llmling_agent.messaging.eventnode import EventNode
     from llmling_agent.messaging.messagenode import MessageNode
     from llmling_agent.models.manifest import AgentsManifest
-    from llmling_agent_config.result_types import StructuredResponseConfig
+    from llmling_agent_config.output_types import StructuredResponseConfig
     from llmling_agent_config.session import SessionQuery
     from llmling_agent_config.task import Job
     from llmling_agent_input.base import InputProvider
@@ -71,7 +74,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
 
     def __init__(
         self,
-        manifest: StrPath | AgentsManifest | None = None,
+        manifest: JoinablePathLike | AgentsManifest | None = None,
         *,
         shared_deps: TPoolDeps | None = None,
         connect_nodes: bool = True,
@@ -101,7 +104,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         match manifest:
             case None:
                 self.manifest = AgentsManifest()
-            case str() | os.PathLike():
+            case str() | os.PathLike() | UPath():
                 self.manifest = AgentsManifest.from_file(manifest)
             case AgentsManifest():
                 self.manifest = manifest
@@ -113,7 +116,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         self.exit_stack = AsyncExitStack()
         self.parallel_load = parallel_load
         self.storage = StorageManager(self.manifest.storage)
-        self.progress_handlers = progress_handlers or []
+        self.progress_handlers = MultiEventHandler[ProgressCallback](progress_handlers)
         self.connection_registry = ConnectionRegistry()
         servers = self.manifest.get_mcp_servers()
         self.mcp = MCPManager(name="pool_mcp", servers=servers, owner="pool")
@@ -123,7 +126,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
             self._tasks.register(name, task)
 
         # Initialize process manager for background processes
-        from llmling_agent.agent.process_manager import ProcessManager
+        from anyenv import ProcessManager
 
         self.process_manager = ProcessManager()
         self.pool_talk = TeamTalk[Any].from_nodes(list(self.nodes.values()))
@@ -138,7 +141,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
                 provider=provider,
                 config=self.manifest.pool_server,
             )
-            self.progress_handlers.append(self.server.report_progress)
+            self.progress_handlers.add_handler(self.server.report_progress)
         else:
             self.server = None
         # Create requested agents immediately
@@ -173,7 +176,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
             # Add MCP server if configured
             if self.server:
                 components.append(self.server)
-
+            components.append(self.storage)
             # Initialize all components
             if self.parallel_load:
                 await asyncio.gather(
@@ -219,7 +222,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         name: str | None = None,
         description: str | None = None,
         shared_prompt: str | None = None,
-        picker: AnyAgent[Any, Any] | None = None,
+        picker: Agent[Any, Any] | None = None,
         num_picks: int | None = None,
         pick_prompt: str | None = None,
     ) -> TeamRun[TPoolDeps, TResult]: ...
@@ -233,7 +236,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         name: str | None = None,
         description: str | None = None,
         shared_prompt: str | None = None,
-        picker: AnyAgent[Any, Any] | None = None,
+        picker: Agent[Any, Any] | None = None,
         num_picks: int | None = None,
         pick_prompt: str | None = None,
     ) -> TeamRun[TDeps, TResult]: ...
@@ -247,7 +250,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         name: str | None = None,
         description: str | None = None,
         shared_prompt: str | None = None,
-        picker: AnyAgent[Any, Any] | None = None,
+        picker: Agent[Any, Any] | None = None,
         num_picks: int | None = None,
         pick_prompt: str | None = None,
     ) -> TeamRun[Any, TResult]: ...
@@ -260,7 +263,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         name: str | None = None,
         description: str | None = None,
         shared_prompt: str | None = None,
-        picker: AnyAgent[Any, Any] | None = None,
+        picker: Agent[Any, Any] | None = None,
         num_picks: int | None = None,
         pick_prompt: str | None = None,
     ) -> TeamRun[Any, TResult]:
@@ -312,7 +315,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         name: str | None = None,
         description: str | None = None,
         shared_prompt: str | None = None,
-        picker: AnyAgent[Any, Any] | None = None,
+        picker: Agent[Any, Any] | None = None,
         num_picks: int | None = None,
         pick_prompt: str | None = None,
     ) -> Team[TDeps]: ...
@@ -325,7 +328,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         name: str | None = None,
         description: str | None = None,
         shared_prompt: str | None = None,
-        picker: AnyAgent[Any, Any] | None = None,
+        picker: Agent[Any, Any] | None = None,
         num_picks: int | None = None,
         pick_prompt: str | None = None,
     ) -> Team[Any]: ...
@@ -337,7 +340,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         name: str | None = None,
         description: str | None = None,
         shared_prompt: str | None = None,
-        picker: AnyAgent[Any, Any] | None = None,
+        picker: Agent[Any, Any] | None = None,
         num_picks: int | None = None,
         pick_prompt: str | None = None,
     ) -> Team[Any]:
@@ -357,13 +360,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         if agents is None:
             agents = list(self.agents.keys())
 
-        # First resolve/configure agents
-        resolved_agents: list[MessageNode[Any, Any]] = []
-        for agent in agents:
-            if isinstance(agent, str):
-                agent = self.get_agent(agent)
-            resolved_agents.append(agent)
-
+        resolved_agents = [self.get_agent(i) if isinstance(i, str) else i for i in agents]
         team = Team(
             name=name,
             description=description,
@@ -398,13 +395,9 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
                 await asyncio.sleep(1)
 
     @property
-    def agents(self) -> dict[str, AnyAgent[Any, Any]]:
+    def agents(self) -> dict[str, Agent[Any, Any]]:
         """Get agents dict (backward compatibility)."""
-        return {
-            i.name: i
-            for i in self._items.values()
-            if isinstance(i, Agent | StructuredAgent)
-        }
+        return {i.name: i for i in self._items.values() if isinstance(i, Agent)}
 
     @property
     def teams(self) -> dict[str, BaseTeam[Any, Any]]:
@@ -494,11 +487,11 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
             source = self[name]
             for target in config.connections or []:
                 match target:
-                    case NodeConnectionConfig():
-                        if target.name not in self:
-                            msg = f"Forward target {target.name} not found for {name}"
+                    case NodeConnectionConfig(name=name_):
+                        if name_ not in self:
+                            msg = f"Forward target {name_} not found for {name}"
                             raise ValueError(msg)
-                        target_node = self[target.name]
+                        target_node = self[name_]
                     case FileConnectionConfig() | CallableConnectionConfig():
                         target_node = Agent(provider=target.get_provider())
                     case _:
@@ -529,86 +522,64 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
                     wait=target.wait_for_completion,
                 )
 
-    @overload
-    async def clone_agent[TDeps](
-        self,
-        agent: AgentName | Agent[TDeps],
-        new_name: AgentName | None = None,
-        *,
-        system_prompts: list[str] | None = None,
-        template_context: dict[str, Any] | None = None,
-    ) -> Agent[TDeps]: ...
+    # async def clone_agent[TDeps, TAgentResult](
+    #     self,
+    #     agent: AgentName | Agent[TDeps, TAgentResult],
+    #     new_name: AgentName | None = None,
+    #     *,
+    #     system_prompts: list[str] | None = None,
+    #     template_context: dict[str, Any] | None = None,
+    # ) -> Agent[TDeps, TAgentResult]:
+    #     """Create a copy of an agent.
 
-    @overload
-    async def clone_agent[TDeps, TResult](
-        self,
-        agent: StructuredAgent[TDeps, TResult],
-        new_name: AgentName | None = None,
-        *,
-        system_prompts: list[str] | None = None,
-        template_context: dict[str, Any] | None = None,
-    ) -> StructuredAgent[TDeps, TResult]: ...
+    #     Args:
+    #         agent: Agent instance or name to clone
+    #         new_name: Optional name for the clone
+    #         system_prompts: Optional different prompts
+    #         template_context: Variables for template rendering
 
-    async def clone_agent[TDeps, TAgentResult](
-        self,
-        agent: AgentName | AnyAgent[TDeps, TAgentResult],
-        new_name: AgentName | None = None,
-        *,
-        system_prompts: list[str] | None = None,
-        template_context: dict[str, Any] | None = None,
-    ) -> AnyAgent[TDeps, TAgentResult]:
-        """Create a copy of an agent.
+    #     Returns:
+    #         The new agent instance
+    #     """
+    #     from llmling_agent.agent import Agent
 
-        Args:
-            agent: Agent instance or name to clone
-            new_name: Optional name for the clone
-            system_prompts: Optional different prompts
-            template_context: Variables for template rendering
+    #     # Get original config
+    #     if isinstance(agent, str):
+    #         if agent not in self.manifest.agents:
+    #             msg = f"Agent {agent} not found"
+    #             raise KeyError(msg)
+    #         config = self.manifest.agents[agent]
+    #         original_agent: Agent[Any, Any] = self.get_agent(agent)
+    #     else:
+    #         config = agent.context.config  # type: ignore
+    #         original_agent = agent
 
-        Returns:
-            The new agent instance
-        """
-        from llmling_agent.agent import Agent, StructuredAgent
+    #     # Create new config
+    #     new_cfg = config.model_copy(deep=True)
 
-        # Get original config
-        if isinstance(agent, str):
-            if agent not in self.manifest.agents:
-                msg = f"Agent {agent} not found"
-                raise KeyError(msg)
-            config = self.manifest.agents[agent]
-            original_agent: AnyAgent[Any, Any] = self.get_agent(agent)
-        else:
-            config = agent.context.config  # type: ignore
-            original_agent = agent
+    #     # Apply overrides
+    #     if system_prompts:
+    #         new_cfg.system_prompts = system_prompts
 
-        # Create new config
-        new_config = config.model_copy(deep=True)
+    #     # Handle template rendering
+    #     if template_context:
+    #         new_cfg.system_prompts = new_cfg.render_system_prompts(template_context)
 
-        # Apply overrides
-        if system_prompts:
-            new_config.system_prompts = system_prompts
-
-        # Handle template rendering
-        if template_context:
-            new_config.system_prompts = new_config.render_system_prompts(template_context)
-
-        # Create new agent with same runtime
-        new_agent = Agent[TDeps](
-            runtime=original_agent.runtime,
-            context=original_agent.context,
-            # result_type=original_agent.actual_type,
-            provider=new_config.get_provider(),
-            system_prompt=new_config.system_prompts,
-            name=new_name or f"{config.name}_copy_{len(self.agents)}",
-        )
-        if isinstance(original_agent, StructuredAgent):
-            new_agent = new_agent.to_structured(original_agent.actual_type)
-
-        # Register in pool
-        agent_name = new_agent.name
-        self.manifest.agents[agent_name] = new_config
-        self.register(agent_name, new_agent)
-        return await self.exit_stack.enter_async_context(new_agent)
+    #     # Create new agent with same runtime
+    #     new_agent = Agent[TDeps](
+    #         runtime=original_agent.runtime,
+    #         context=original_agent.context,
+    #         output_type=original_agent._output_type,
+    #         # output_type=original_agent.actual_type,
+    #         provider=new_cfg.get_provider(),
+    #         system_prompt=new_cfg.system_prompts,
+    #         name=new_name or f"{config.name}_copy_{len(self.agents)}",
+    #     )
+    #     # Register in pool
+    #     agent_name = new_agent.name
+    #     self.manifest.agents[agent_name] = new_cfg
+    #     self.register(agent_name, new_agent)
+    #     return await self.exit_stack.enter_async_context(new_agent)
 
     @overload
     async def create_agent(
@@ -637,7 +608,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         return_type: type[TResult],
         session: SessionIdType | SessionQuery = None,
         name_override: str | None = None,
-    ) -> StructuredAgent[TPoolDeps, TResult]: ...
+    ) -> Agent[TPoolDeps, TResult]: ...
 
     @overload
     async def create_agent[TCustomDeps, TResult](
@@ -648,7 +619,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         return_type: type[TResult],
         session: SessionIdType | SessionQuery = None,
         name_override: str | None = None,
-    ) -> StructuredAgent[TCustomDeps, TResult]: ...
+    ) -> Agent[TCustomDeps, TResult]: ...
 
     async def create_agent(
         self,
@@ -658,7 +629,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         return_type: Any | None = None,
         session: SessionIdType | SessionQuery = None,
         name_override: str | None = None,
-    ) -> AnyAgent[Any, Any]:
+    ) -> Agent[Any, Any]:
         """Create a new agent instance from configuration.
 
         Args:
@@ -698,11 +669,11 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
 
         # Override structured configuration if provided
         if return_type is not None:
-            return agent.to_structured(return_type)
+            agent.set_output_type(return_type)
 
         return agent
 
-    def setup_agent_workers(self, agent: AnyAgent[Any, Any]):
+    def setup_agent_workers(self, agent: Agent[Any, Any]):
         """Set up workers for an agent from configuration."""
         for worker_config in agent.context.config.workers:
             try:
@@ -715,7 +686,6 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
                             worker,
                             reset_history_on_run=worker_config.reset_history_on_run,
                             pass_message_history=worker_config.pass_message_history,
-                            share_context=worker_config.share_context,
                         )
             except KeyError as e:
                 msg = f"Worker agent {worker_config.name!r} not found"
@@ -724,7 +694,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
     @overload
     def get_agent(
         self,
-        agent: AgentName | Agent[Any],
+        agent: AgentName | Agent[Any, str],
         *,
         model_override: str | None = None,
         session: SessionIdType | SessionQuery = None,
@@ -733,17 +703,17 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
     @overload
     def get_agent[TResult](
         self,
-        agent: AgentName | Agent[Any],
+        agent: AgentName | Agent[Any, str],
         *,
         return_type: type[TResult],
         model_override: str | None = None,
         session: SessionIdType | SessionQuery = None,
-    ) -> StructuredAgent[TPoolDeps, TResult]: ...
+    ) -> Agent[TPoolDeps, TResult]: ...
 
     @overload
     def get_agent[TCustomDeps](
         self,
-        agent: AgentName | Agent[Any],
+        agent: AgentName | Agent[Any, str],
         *,
         deps: TCustomDeps,
         model_override: str | None = None,
@@ -753,29 +723,28 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
     @overload
     def get_agent[TCustomDeps, TResult](
         self,
-        agent: AgentName | Agent[Any],
+        agent: AgentName | Agent[Any, str],
         *,
         deps: TCustomDeps,
         return_type: type[TResult],
         model_override: str | None = None,
         session: SessionIdType | SessionQuery = None,
-    ) -> StructuredAgent[TCustomDeps, TResult]: ...
+    ) -> Agent[TCustomDeps, TResult]: ...
 
     def get_agent(
         self,
-        agent: AgentName | Agent[Any],
+        agent: AgentName | Agent[Any, str],
         *,
         deps: Any | None = None,
         return_type: Any | None = None,
         model_override: str | None = None,
         session: SessionIdType | SessionQuery = None,
-    ) -> AnyAgent[Any, Any]:
+    ) -> Agent[Any, Any]:
         """Get or configure an agent from the pool.
 
         This method provides flexible agent configuration with dependency injection:
         - Without deps: Agent uses pool's shared dependencies
         - With deps: Agent uses provided custom dependencies
-        - With return_type: Returns a StructuredAgent with type validation
 
         Args:
             agent: Either agent name or instance
@@ -788,7 +757,6 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
             Either:
             - Agent[TPoolDeps] when using pool's shared deps
             - Agent[TCustomDeps] when custom deps provided
-            - StructuredAgent when return_type provided
 
         Raises:
             KeyError: If agent name not found
@@ -817,7 +785,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
 
         # Convert to structured if needed
         if return_type is not None:
-            return base.to_structured(return_type)
+            base.set_output_type(return_type)
 
         return base
 
@@ -831,36 +799,18 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
     def register_task(self, name: str, task: Job[Any, Any]):
         self._tasks.register(name, task)
 
-    @overload
-    async def add_agent(
+    async def add_agent[TResult = str](
         self,
         name: AgentName,
         *,
-        result_type: None = None,
+        output_type: OutputSpec[TResult] | str | StructuredResponseConfig = str,  # type: ignore[assignment]
         **kwargs: Unpack[AgentKwargs],
-    ) -> Agent[Any]: ...
-
-    @overload
-    async def add_agent[TResult](
-        self,
-        name: AgentName,
-        *,
-        result_type: type[TResult] | str | StructuredResponseConfig,
-        **kwargs: Unpack[AgentKwargs],
-    ) -> StructuredAgent[Any, TResult]: ...
-
-    async def add_agent(
-        self,
-        name: AgentName,
-        *,
-        result_type: type[Any] | str | StructuredResponseConfig | None = None,
-        **kwargs: Unpack[AgentKwargs],
-    ) -> Agent[Any] | StructuredAgent[Any, Any]:
+    ) -> Agent[Any, TResult]:
         """Add a new permanent agent to the pool.
 
         Args:
             name: Name for the new agent
-            result_type: Optional type for structured responses:
+            output_type: Optional type for structured responses:
                 - None: Regular unstructured agent
                 - type: Python type for validation
                 - str: Name of response definition
@@ -868,23 +818,17 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
             **kwargs: Additional agent configuration
 
         Returns:
-            Either a regular Agent or StructuredAgent depending on result_type
+            An agent instance
         """
         from llmling_agent.agent import Agent
 
-        agent: AnyAgent[Any, Any] = Agent(name=name, **kwargs)
+        agent: Agent[Any, TResult] = Agent(name=name, **kwargs, output_type=output_type)
         agent.tools.add_provider(self.mcp)
         agent = await self.exit_stack.enter_async_context(agent)
-        # Convert to structured if needed
-        if result_type is not None:
-            agent = agent.to_structured(result_type)
         self.register(name, agent)
         return agent
 
-    def get_mermaid_diagram(
-        self,
-        include_details: bool = True,
-    ) -> str:
+    def get_mermaid_diagram(self, include_details: bool = True) -> str:
         """Generate mermaid flowchart of all agents and their connections.
 
         Args:
@@ -928,7 +872,7 @@ if __name__ == "__main__":
     async def main():
         path = "src/llmling_agent/config_resources/agents.yml"
         async with AgentPool[None](path) as pool:
-            agent: Agent[None] = pool.get_agent("overseer")
+            agent: Agent[None, Any] = pool.get_agent("overseer")
             print(agent)
 
     import asyncio
