@@ -23,7 +23,7 @@ if TYPE_CHECKING:
     import os
 
     import PIL.Image
-    from pydantic_ai.messages import AgentStreamEvent
+    from pydantic_ai import AgentStreamEvent
     from toprompt import AnyPromptType
 
     from llmling_agent import MessageNode
@@ -123,7 +123,7 @@ class Team[TDeps](BaseTeam[TDeps, Any]):
         """Format team info for prompts."""
         members = ", ".join(a.name for a in self.agents)
         desc = f" - {self.description}" if self.description else ""
-        return f"Parallel Team '{self.name}'{desc}\nMembers: {members}"
+        return f"Parallel Team {self.name!r}{desc}\nMembers: {members}"
 
     async def run_iter(
         self,
@@ -248,7 +248,7 @@ class Team[TDeps](BaseTeam[TDeps, Any]):
             JobError: If job execution fails for any agent
             ValueError: If job configuration is invalid
         """
-        from llmling_agent.agent import Agent, StructuredAgent
+        from llmling_agent.agent import Agent
         from llmling_agent.tasks import JobError
 
         responses: list[AgentResponse[TJobResult]] = []
@@ -279,7 +279,7 @@ class Team[TDeps](BaseTeam[TDeps, Any]):
             prompt = await job.get_prompt()
 
             async def _run(agent: MessageNode[TDeps, TJobResult]):
-                assert isinstance(agent, Agent | StructuredAgent)
+                assert isinstance(agent, Agent)
                 try:
                     with agent.tools.temporary_tools(
                         job.get_tools(), exclusive=not include_agent_tools
