@@ -23,11 +23,11 @@ if TYPE_CHECKING:
     import os
 
     import PIL.Image
-    from pydantic_ai.messages import AgentStreamEvent
+    from pydantic_ai import AgentStreamEvent
     from toprompt import AnyPromptType
 
     from llmling_agent import MessageNode
-    from llmling_agent.agent import AnyAgent
+    from llmling_agent.agent import Agent
     from llmling_agent.agent.agent import StreamCompleteEvent
 
 
@@ -69,7 +69,7 @@ class TeamRun[TDeps, TResult](BaseTeam[TDeps, TResult]):
         description: str | None = None,
         shared_prompt: str | None = None,
         validator: MessageNode[Any, TResult],
-        picker: AnyAgent[Any, Any] | None = None,
+        picker: Agent[Any, Any] | None = None,
         num_picks: int | None = None,
         pick_prompt: str | None = None,
     ): ...
@@ -83,7 +83,7 @@ class TeamRun[TDeps, TResult](BaseTeam[TDeps, TResult]):
         description: str | None = None,
         shared_prompt: str | None = None,
         validator: None = None,
-        picker: AnyAgent[Any, Any] | None = None,
+        picker: Agent[Any, Any] | None = None,
         num_picks: int | None = None,
         pick_prompt: str | None = None,
     ): ...
@@ -97,7 +97,7 @@ class TeamRun[TDeps, TResult](BaseTeam[TDeps, TResult]):
         description: str | None = None,
         shared_prompt: str | None = None,
         validator: MessageNode[Any, TResult] | None = None,
-        picker: AnyAgent[Any, Any] | None = None,
+        picker: Agent[Any, Any] | None = None,
         num_picks: int | None = None,
         pick_prompt: str | None = None,
     ): ...
@@ -110,7 +110,7 @@ class TeamRun[TDeps, TResult](BaseTeam[TDeps, TResult]):
         description: str | None = None,
         shared_prompt: str | None = None,
         validator: MessageNode[Any, TResult] | None = None,
-        picker: AnyAgent[Any, Any] | None = None,
+        picker: Agent[Any, Any] | None = None,
         num_picks: int | None = None,
         pick_prompt: str | None = None,
         # result_mode: ResultMode = "last",
@@ -131,7 +131,7 @@ class TeamRun[TDeps, TResult](BaseTeam[TDeps, TResult]):
         """Format team info for prompts."""
         members = " -> ".join(a.name for a in self.agents)
         desc = f" - {self.description}" if self.description else ""
-        return f"Sequential Team '{self.name}'{desc}\nPipeline: {members}"
+        return f"Sequential Team {self.name!r}{desc}\nPipeline: {members}"
 
     async def _run(
         self,
@@ -278,7 +278,7 @@ class TeamRun[TDeps, TResult](BaseTeam[TDeps, TResult]):
             Tuples of (agent, event) where agent is the Agent instance
             and event is the streaming event.
         """
-        from pydantic_ai.messages import PartDeltaEvent, TextPartDelta
+        from pydantic_ai import PartDeltaEvent, TextPartDelta
 
         from llmling_agent.agent.agent import StreamCompleteEvent
 
