@@ -13,11 +13,7 @@ from llmling_agent.log import get_logger
 from llmling_agent.mcp_server.client import MCPClient
 from llmling_agent.models.content import AudioBase64Content, ImageBase64Content
 from llmling_agent.resource_providers.base import ResourceProvider
-from llmling_agent_config.mcp_server import (
-    SSEMCPServerConfig,
-    StdioMCPServerConfig,
-    StreamableHTTPMCPServerConfig,
-)
+from llmling_agent_config.mcp_server import BaseMCPServerConfig
 from llmling_agent_config.resources import ResourceInfo
 from llmling_agent_providers.base import UsageLimits
 
@@ -25,11 +21,12 @@ from llmling_agent_providers.base import UsageLimits
 if TYPE_CHECKING:
     from collections.abc import Sequence
 
+    from fastmcp.client.elicitation import ElicitResult
     from mcp import types
     from mcp.client.session import RequestContext
-    from mcp.types import Prompt as MCPPrompt, Resource as MCPResource
+    from mcp.types import Prompt as MCPPrompt, Resource as MCPResource, SamplingMessage
 
-    from llmling_agent.mcp_server.progress import ProgressHandler
+    from llmling_agent.mcp_server.client import ContextualProgressHandler
     from llmling_agent.messaging.context import NodeContext
     from llmling_agent.models.content import BaseContent
     from llmling_agent.tools.base import Tool
@@ -69,7 +66,7 @@ class MCPManager(ResourceProvider):
         owner: str | None = None,
         servers: Sequence[MCPServerConfig | str] | None = None,
         context: NodeContext | None = None,
-        progress_handler: ProgressHandler | None = None,
+        progress_handler: ContextualProgressHandler | None = None,
         accessible_roots: list[str] | None = None,
     ):
         super().__init__(name, owner=owner)
@@ -82,32 +79,26 @@ class MCPManager(ResourceProvider):
         self._progress_handler = progress_handler
         self._accessible_roots = accessible_roots
 
-    @property
-    def requires_async(self) -> bool:
-        return True
-
-    def add_server_config(self, server: MCPServerConfig | str):
+    def add_server_config(self, cfg: MCPServerConfig | str):
         """Add a new MCP server to the manager."""
-        server = (
-            StdioMCPServerConfig.from_string(server)
-            if isinstance(server, str)
-            else server
-        )
-        self.servers.append(server)
+        resolved = BaseMCPServerConfig.from_string(cfg) if isinstance(cfg, str) else cfg
+        self.servers.append(resolved)
 
     def __repr__(self) -> str:
         return f"MCPManager({self.servers!r})"
 
     async def __aenter__(self) -> Self:
         try:
-            # Setup directly provided servers
-            for server in self.servers:
-                await self.setup_server(server)
-
-            # Setup servers from context if available
+            # Setup directly provided servers and context servers concurrently
+            tasks = [self.setup_server(server) for server in self.servers]
             if self.context and self.context.config and self.context.config.mcp_servers:
-                for server in self.context.config.get_mcp_servers():
-                    await self.setup_server(server)
+                tasks.extend(
+                    self.setup_server(server)
+                    for server in self.context.config.get_mcp_servers()
+                )
+
+            if tasks:
+                await asyncio.gather(*tasks)
 
         except Exception as e:
             # Clean up in case of error
@@ -122,35 +113,45 @@ class MCPManager(ResourceProvider):
 
     async def _elicitation_callback(
         self,
-        context: RequestContext,
+        message: str,
+        response_type: type[Any],
         params: types.ElicitRequestParams,
-    ) -> types.ElicitResult | types.ErrorData:
+        context: RequestContext,
+    ) -> ElicitResult[dict[str, Any]] | dict[str, Any] | None:
         """Handle elicitation requests from MCP server."""
+        from fastmcp.client.elicitation import ElicitResult
         from mcp import types
 
         from llmling_agent.agent.context import AgentContext
 
         if self.context and isinstance(self.context, AgentContext):
-            return await self.context.handle_elicitation(params)
-        return types.ErrorData(
-            code=types.INVALID_REQUEST,
-            message="Elicitation not supported - no agent context available",
-        )
+            legacy_result = await self.context.handle_elicitation(params)
+            # Convert legacy MCP result to FastMCP format
+            if isinstance(legacy_result, types.ElicitResult):
+                if legacy_result.action == "accept" and legacy_result.content:
+                    return legacy_result.content
+                return ElicitResult(action=legacy_result.action)
+            if isinstance(legacy_result, types.ErrorData):
+                return ElicitResult(action="cancel")
+            return ElicitResult(action="decline")
+
+        return ElicitResult(action="decline")
 
     async def _sampling_callback(
         self,
-        context: RequestContext,
+        messages: list[SamplingMessage],
         params: types.CreateMessageRequestParams,
-    ) -> types.CreateMessageResult | types.ErrorData:
+        context: RequestContext,
+    ) -> str:
         """Handle MCP sampling by creating a new agent with specified preferences."""
         from mcp import types
 
         from llmling_agent.agent import Agent
 
         try:
-            # Convert MCP messages to prompts for the agent
+            # Convert messages to prompts for the agent
             prompts: list[BaseContent | str] = []
-            for mcp_msg in params.messages:
+            for mcp_msg in messages:
                 match mcp_msg.content:
                     case types.TextContent(text=text):
                         prompts.append(text)
@@ -182,7 +183,7 @@ class MCPManager(ResourceProvider):
             # May need provider-level configuration or runtime model settings
 
             # Create agent with sampling parameters
-            agent: Agent[Any] = Agent(
+            agent = Agent(
                 name="mcp-sampling-agent",
                 model=model,
                 system_prompt=params.systemPrompt or "",
@@ -197,112 +198,92 @@ class MCPManager(ResourceProvider):
                     usage_limits=usage_limits,
                 )
 
-                return types.CreateMessageResult(
-                    role="assistant",
-                    content=types.TextContent(type="text", text=str(result.content)),
-                    model=result.model or "unknown",
-                    stopReason="endTurn",  # Could detect actual stop reason from result
-                )
+                return str(result.content)
 
         except Exception as e:
             logger.exception("Sampling failed")
-            return types.ErrorData(
-                code=types.INTERNAL_ERROR,
-                message=f"Sampling failed: {e!s}",
-            )
+            return f"Sampling failed: {e!s}"
 
-    async def setup_server(self, config: MCPServerConfig):
+    async def setup_server(self, config: MCPServerConfig) -> None:
         """Set up a single MCP server connection."""
         if not config.enabled:
             return
-        env = config.get_env_vars()
-        match config:
-            case StdioMCPServerConfig(command=command, args=args):
-                client = MCPClient(
-                    transport_mode="stdio",
-                    elicitation_callback=self._elicitation_callback,
-                    sampling_callback=self._sampling_callback,
-                    progress_handler=self._progress_handler,
-                    accessible_roots=self._accessible_roots,
-                )
-                client = await self.exit_stack.enter_async_context(client)
-                await client.connect(command, args=args, env=env)
-                client_id = f"{command}_{' '.join(args)}"
-            case SSEMCPServerConfig(url=url):
-                client = MCPClient(
-                    transport_mode="sse",
-                    elicitation_callback=self._elicitation_callback,
-                    sampling_callback=self._sampling_callback,
-                    progress_handler=self._progress_handler,
-                    accessible_roots=self._accessible_roots,
-                )
-                client = await self.exit_stack.enter_async_context(client)
-                await client.connect("", [], url=url, env=env)
-                client_id = f"sse_{url}"
-            case StreamableHTTPMCPServerConfig(url=url):
-                client = MCPClient(
-                    transport_mode="streamable-http",
-                    elicitation_callback=self._elicitation_callback,
-                    sampling_callback=self._sampling_callback,
-                    progress_handler=self._progress_handler,
-                    accessible_roots=self._accessible_roots,
-                )
-                client = await self.exit_stack.enter_async_context(client)
-                await client.connect("", [], url=url, env=env)
-                client_id = f"streamable_http_{url}"
-        self.clients[client_id] = client
+
+        client = MCPClient(
+            config=config,
+            elicitation_callback=self._elicitation_callback,
+            sampling_callback=self._sampling_callback,
+            progress_handler=self._progress_handler,
+            accessible_roots=self._accessible_roots,
+        )
+        client = await self.exit_stack.enter_async_context(client)
+
+        self.clients[config.client_id] = client
 
     async def get_tools(self) -> list[Tool]:
         """Get all tools from all connected servers."""
-        from llmling_agent.tools.base import Tool
+        all_tools: list[Tool] = []
 
-        tools: list[Tool] = []
         for client in self.clients.values():
             for tool in client._available_tools:
                 try:
-                    fn = client.create_tool_callable(tool)
-                    meta = {"mcp_tool": tool.name}
-                    tool_info = Tool.from_callable(fn, source="mcp", metadata=meta)
-                    tools.append(tool_info)
-                    logger.debug("Registered MCP tool: %s", tool.name)
+                    tool_info = client.convert_tool(tool)
+                    all_tools.append(tool_info)
                 except Exception:
                     msg = "Failed to create tool from MCP tool: %s"
                     logger.exception(msg, tool.name)
                     continue
-
-        return tools
+        logger.debug("Fetched %s MCP tools", len(all_tools))
+        return all_tools
 
     async def list_prompts(self) -> list[StaticPrompt]:
         """Get all available prompts from MCP servers."""
-        prompts = []
-        for client in self.clients.values():
+
+        async def get_client_prompts(client: MCPClient) -> list[StaticPrompt]:
             try:
                 result = await client.list_prompts()
+                client_prompts: list[StaticPrompt] = []
+                for prompt in result:
+                    try:
+                        converted = await convert_mcp_prompt(client, prompt)
+                        client_prompts.append(converted)
+                    except Exception:
+                        logger.exception("Failed to convert prompt: %s", prompt.name)
             except Exception:
                 logger.exception("Failed to get prompts from MCP server")
-            for prompt in result.prompts:
-                try:
-                    converted = await convert_mcp_prompt(client, prompt)
-                    prompts.append(converted)
-                except Exception:
-                    logger.exception("Failed to convert prompt: %s", prompt.name)
-        return prompts
+                return []
+            else:
+                return client_prompts
+
+        results = await asyncio.gather(*[
+            get_client_prompts(client) for client in self.clients.values()
+        ])
+        return [prompt for client_prompts in results for prompt in client_prompts]
 
     async def list_resources(self) -> list[ResourceInfo]:
         """Get all available resources from MCP servers."""
-        resources = []
-        for client in self.clients.values():
+
+        async def get_client_resources(client: MCPClient) -> list[ResourceInfo]:
             try:
                 result = await client.list_resources()
+                client_resources: list[ResourceInfo] = []
+                for resource in result:
+                    try:
+                        converted = await convert_mcp_resource(resource)
+                        client_resources.append(converted)
+                    except Exception:
+                        logger.exception("Failed to convert resource: %s", resource.name)
             except Exception:
                 logger.exception("Failed to get resources from MCP server")
-            for resource in result.resources:
-                try:
-                    converted = await convert_mcp_resource(resource)
-                    resources.append(converted)
-                except Exception:
-                    logger.exception("Failed to convert resource: %s", resource.name)
-        return resources
+                return []
+            else:
+                return client_resources
+
+        results = await asyncio.gather(
+            *[get_client_resources(client) for client in self.clients.values()],
+            return_exceptions=False,
+        )
+        return [resource for client_resources in results for resource in client_resources]
 
     async def cleanup(self) -> None:
         """Clean up all MCP connections."""
