@@ -128,9 +128,10 @@ class EventNode[TEventData](MessageEmitter[None, TEventData]):
         """Stop monitoring for events."""
         self._running = False
 
-    @property
-    def stats(self) -> MessageStats:
-        return MessageStats(messages=self._logger.message_history)
+    async def get_stats(self) -> MessageStats:
+        """Get message statistics (async version)."""
+        messages = await self.get_message_history()
+        return MessageStats(messages=messages)
 
     async def _run(self, *content: Any, **kwargs: Any) -> ChatMessage[TEventData]:
         """Convert event data to message."""
