@@ -24,6 +24,7 @@ if TYPE_CHECKING:
     from toprompt import AnyPromptType
 
     from llmling_agent.models.content import Content
+    from llmling_agent.talk.stats import AggregatedMessageStats, MessageStats
 
 
 class MessageNode[TDeps, TResult](MessageEmitter[TDeps, TResult]):
@@ -83,32 +84,56 @@ class MessageNode[TDeps, TResult](MessageEmitter[TDeps, TResult]):
     #     # Set conversation_id on response message
     #     message = replace(message, conversation_id=conversation_id)
     #     self.message_sent.emit(message)
+    #     await self.log_message(response_msg)
     #     await self.connections.route_message(message, wait=wait_for_connections)
     #     return message
 
+    # @overload
+    # async def run(
+    #     self,
+    #     *prompt: AnyPromptType | PIL.Image.Image | os.PathLike[str] | ChatMessage,
+    #     wait_for_connections: bool | None = None,
+    #     store_history: bool = True,
+    #     output_type: None,
+    #     **kwargs: Any,
+    # ) -> ChatMessage[TResult]: ...
+
+    # @overload
+    # async def run[OutputTypeT](
+    #     self,
+    #     *prompt: AnyPromptType | PIL.Image.Image | os.PathLike[str] | ChatMessage,
+    #     wait_for_connections: bool | None = None,
+    #     store_history: bool = True,
+    #     output_type: type[OutputTypeT],
+    #     **kwargs: Any,
+    # ) -> ChatMessage[OutputTypeT]: ...
+
     @method_spawner
-    async def run(
+    async def run[OutputTypeT](
         self,
         *prompt: AnyPromptType | PIL.Image.Image | os.PathLike[str] | ChatMessage,
         wait_for_connections: bool | None = None,
         store_history: bool = True,
+        output_type: type[OutputTypeT] | None = None,
         **kwargs: Any,
-    ) -> ChatMessage[TResult]:
+    ) -> ChatMessage[Any]:
         """Execute node with prompts and handle message routing.
 
         Args:
             prompt: Input prompts
             wait_for_connections: Whether to wait for forwarded messages
             store_history: Whether to store in conversation history
+            output_type: Type of output to expect
             **kwargs: Additional arguments for _run
         """
-        from llmling_agent import Agent, StructuredAgent
+        from llmling_agent import Agent
 
         user_msg, prompts = await self.pre_run(*prompt)
         message = await self._run(
             *prompts,
             store_history=store_history,
             conversation_id=user_msg.conversation_id,
+            output_type=output_type,
             **kwargs,
         )
 
@@ -116,12 +141,16 @@ class MessageNode[TDeps, TResult](MessageEmitter[TDeps, TResult]):
         if len(prompt) == 1 and isinstance(prompt[0], ChatMessage):
             message = message.forwarded(prompt[0])
 
-        if store_history and isinstance(self, Agent | StructuredAgent):
+        if store_history and isinstance(self, Agent):
             self.conversation.add_chat_messages([user_msg, message])
         self.message_sent.emit(message)
         await self.connections.route_message(message, wait=wait_for_connections)
         return message
 
+    @abstractmethod
+    async def get_stats(self) -> MessageStats | AggregatedMessageStats:
+        """Get message statistics for this node."""
+
     @abstractmethod
     def run_iter(
         self,
