@@ -14,7 +14,8 @@ from llmling_agent_config.converters import (
 
 
 if TYPE_CHECKING:
-    from llmling_agent.common_types import StrPath
+    from upath.types import JoinablePathLike
+
     from llmling_agent_converters.base import DocumentConverter
 
 
@@ -37,7 +38,7 @@ class ConversionManager:
     def __del__(self):
         self._executor.shutdown(wait=False)
 
-    def supports_file(self, path: StrPath) -> bool:
+    def supports_file(self, path: JoinablePathLike) -> bool:
         """Check if any converter supports the file."""
         return any(c.supports_file(path) for c in self._converters)
 
@@ -49,18 +50,13 @@ class ConversionManager:
         """Create converter instances from config."""
         from llmling_agent_converters.plain_converter import PlainConverter
 
-        converters: list[DocumentConverter] = []
-        for cfg in self.config.providers or []:
-            if not cfg.enabled:
-                continue
-            converter = cfg.get_converter()
-            converters.append(converter)
+        converters = [i.get_converter() for i in self.config.providers or [] if i.enabled]
         # Always add PlainConverter as fallback
         # if it gets configured by user, that one gets preference.
         converters.append(PlainConverter())
         return converters
 
-    async def convert_file(self, path: StrPath) -> str:
+    async def convert_file(self, path: JoinablePathLike) -> str:
         """Convert file using first supporting converter."""
         loop = asyncio.get_running_loop()
         content = await read_path(path, "rb")
@@ -103,24 +99,6 @@ class ConversionManager:
 
         return str(content)  # Fallback for unsupported content
 
-    def convert_file_sync(self, path: StrPath) -> str:
-        """Sync wrapper for convert_file."""
-        try:
-            loop = asyncio.get_running_loop()
-            return loop.run_until_complete(self.convert_file(path))
-        except RuntimeError:
-            # No running loop - create new one
-            return asyncio.run(self.convert_file(path))
-
-    def convert_content_sync(self, content: Any, mime_type: str | None = None) -> str:
-        """Sync wrapper for convert_content."""
-        try:
-            loop = asyncio.get_running_loop()
-            return loop.run_until_complete(self.convert_content(content, mime_type))
-        except RuntimeError:
-            # No running loop - create new one
-            return asyncio.run(self.convert_content(content, mime_type))
-
 
 if __name__ == "__main__":
     from llmling_agent_config.converters import ConversionConfig
@@ -132,4 +110,3 @@ if __name__ == "__main__":
         ]
     )
     manager = ConversionManager(config)
-    print(manager.convert_file_sync("pyproject.toml"))
