@@ -4,6 +4,8 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Self
 
+from llmling_agent.log import get_logger
+
 
 if TYPE_CHECKING:
     from llmling import BasePrompt
@@ -13,6 +15,9 @@ if TYPE_CHECKING:
     from llmling_agent_config.resources import ResourceInfo
 
 
+logger = get_logger(__name__)
+
+
 class ResourceProvider:
     """Base class for resource providers.
 
@@ -24,6 +29,7 @@ class ResourceProvider:
         """Initialize the resource provider."""
         self.name = name
         self.owner = owner
+        self.log = logger.bind(name=self.name, owner=self.owner)
 
     async def __aenter__(self) -> Self:
         """Async context entry if required."""
@@ -35,10 +41,6 @@ class ResourceProvider:
     def __repr__(self) -> str:
         return f"{self.__class__.__name__}(name={self.name!r})"
 
-    @property
-    def requires_async(self) -> bool:
-        return False
-
     async def get_tools(self) -> list[Tool]:
         """Get available tools. Override to provide tools."""
         return []
