@@ -153,16 +153,12 @@ class Talk[TTransmittedData]:
             connection >> other_agent  # Connect to single agent
             connection >> (agent2 & agent3)  # Connect to group
         """
-        from llmling_agent import Agent, MessageNode, StructuredAgent
+        from llmling_agent import Agent, MessageNode
         from llmling_agent.talk import TeamTalk
-        from llmling_agent.utils.inspection import has_return_type
 
         match other:
             case Callable():
-                if has_return_type(other, str):
-                    other = Agent.from_callback(other)
-                else:
-                    other = StructuredAgent.from_callback(other)
+                other = Agent.from_callback(other)
                 if pool := self.source.context.pool:
                     pool.register(other.name, other)
                 return self.__rshift__(other)
@@ -314,7 +310,7 @@ class Talk[TTransmittedData]:
         prompt: AnyPromptType | PIL.Image.Image | os.PathLike[str] | None = None,
     ) -> ChatMessage[Any] | None:
         """Process message for a single target."""
-        from llmling_agent.agent import Agent, StructuredAgent
+        from llmling_agent.agent import Agent
         from llmling_agent.delegation.base_team import BaseTeam
 
         match self.connection_type:
@@ -330,7 +326,7 @@ class Talk[TTransmittedData]:
                 meta = {
                     "type": "forwarded_message",
                     "role": message.role,
-                    "model": message.model,
+                    "model": message.model_name,
                     "cost_info": message.cost_info,
                     "timestamp": message.timestamp.isoformat(),
                     "prompt": prompt,
@@ -341,7 +337,7 @@ class Talk[TTransmittedData]:
                         case BaseTeam():
                             # Use distribute for teams
                             await target.distribute(str(message.content), metadata=meta)
-                        case Agent() | StructuredAgent():  # Agent case
+                        case Agent():  # Agent case
                             # Use existing context message approach
                             target.conversation.add_context_message(
                                 str(message.content),
@@ -527,16 +523,12 @@ class TeamTalk[TTransmittedData](list["Talk | TeamTalk"]):
             connection >> other_agent  # Connect to single agent
             connection >> (agent2 & agent3)  # Connect to group
         """
-        from llmling_agent import Agent, MessageNode, StructuredAgent
+        from llmling_agent import Agent, MessageNode
         from llmling_agent.talk import TeamTalk
-        from llmling_agent.utils.inspection import has_return_type
 
         match other:
             case Callable():
-                if has_return_type(other, str):
-                    other = Agent.from_callback(other)
-                else:
-                    other = StructuredAgent.from_callback(other)
+                other = Agent.from_callback(other)
                 for talk_ in self.iter_talks():
                     if pool := talk_.source.context.pool:
                         pool.register(other.name, other)
