@@ -6,8 +6,8 @@ from typing import Any
 
 from llmling.core.baseregistry import BaseRegistry
 
-from llmling_agent.models.task import Job
 from llmling_agent.tasks.exceptions import JobRegistrationError
+from llmling_agent_config.task import Job
 
 
 class TaskRegistry(BaseRegistry[str, Job[Any, Any]]):
