@@ -14,11 +14,11 @@ from acp.schema import ToolCallLocation
 from llmling_agent.log import get_logger
 from llmling_agent.resource_providers.base import ResourceProvider
 from llmling_agent.tools.base import Tool
-from llmling_agent_tools.file_editor import replace_content
+from llmling_agent_acp.syntax_detection import format_zed_code_block
+from llmling_agent_toolsets.builtin.file_edit import replace_content
 
 
 if TYPE_CHECKING:
-    from acp.schema import ClientCapabilities
     from llmling_agent_acp.session import ACPSession
 
 logger = get_logger(__name__)
@@ -32,25 +32,18 @@ class ACPFileSystemProvider(ResourceProvider):
     eliminating the need for parameter injection.
     """
 
-    def __init__(
-        self,
-        session: ACPSession,
-        client_capabilities: ClientCapabilities,
-        cwd: str | None = None,
-    ):
+    def __init__(self, session: ACPSession):
         """Initialize filesystem provider.
 
         Args:
             session: Session for all tools created by this provider
-            client_capabilities: Client-reported capabilities
-            cwd: Current working directory for relative path resolution
         """
         super().__init__(name=f"acp_filesystem_{session.session_id}")
         self.agent = session.acp_agent
         self.session_id = session.session_id
         self.session = session
-        self.client_capabilities = client_capabilities
-        self.cwd = cwd
+        self.client_capabilities = session.client_capabilities
+        self.cwd = session.cwd
 
     def _resolve_path(self, path: str) -> str:
         """Resolve a potentially relative path to an absolute path.
@@ -71,7 +64,7 @@ class ACPFileSystemProvider(ResourceProvider):
     async def get_tools(self) -> list[Tool]:
         """Get filesystem tools based on client capabilities."""
         tools: list[Tool] = []
-        if fs_caps := self.client_capabilities.fs:
+        if self.client_capabilities and (fs_caps := self.client_capabilities.fs):
             if fs_caps.read_text_file:
                 tool = Tool.from_callable(
                     self.read_text_file, source="filesystem", category="read"
@@ -132,7 +125,7 @@ class ACPFileSystemProvider(ResourceProvider):
                 locations=[ToolCallLocation(path=resolved_path)],
             )
         except Exception as e:  # noqa: BLE001
-            logger.warning("Failed to send pending update: %s", e)
+            self.log.warning("Failed to send pending update", error=e)
 
         try:
             content = await self.session.requests.read_text_file(
@@ -148,10 +141,10 @@ class ACPFileSystemProvider(ResourceProvider):
                     tool_call_id=ctx.tool_call_id,
                     status="completed",
                     locations=[ToolCallLocation(path=resolved_path)],
-                    content=[f"````\n{content}\n````"],
+                    content=[format_zed_code_block(content, resolved_path)],
                 )
             except Exception as e:  # noqa: BLE001
-                logger.warning("Failed to send completed update: %s", e)
+                self.log.warning("Failed to send completed update", error=e)
 
         except Exception as e:  # noqa: BLE001
             # Send failed update
@@ -163,7 +156,7 @@ class ACPFileSystemProvider(ResourceProvider):
                     raw_output=f"Error: {e}",
                 )
             except Exception:  # noqa: BLE001
-                logger.warning("Failed to send failed update")
+                self.log.warning("Failed to send failed update")
 
             return f"Error reading file: {e}"
         else:
@@ -196,7 +189,7 @@ class ACPFileSystemProvider(ResourceProvider):
                 locations=[ToolCallLocation(path=resolved_path)],
             )
         except Exception as e:  # noqa: BLE001
-            logger.warning("Failed to send pending update: %s", e)
+            self.log.warning("Failed to send pending update", error=e)
 
         try:
             await self.session.requests.write_text_file(resolved_path, content=content)
@@ -206,10 +199,10 @@ class ACPFileSystemProvider(ResourceProvider):
                     tool_call_id=ctx.tool_call_id,
                     status="completed",
                     locations=[ToolCallLocation(path=resolved_path)],
-                    content=[content],
+                    content=[format_zed_code_block(content, resolved_path)],
                 )
             except Exception as e:  # noqa: BLE001
-                logger.warning("Failed to send completed update: %s", e)
+                self.log.warning("Failed to send completed update", error=e)
 
         except Exception as e:  # noqa: BLE001
             # Send failed update
@@ -220,7 +213,7 @@ class ACPFileSystemProvider(ResourceProvider):
                     raw_output=f"Error: {e}",
                 )
             except Exception:  # noqa: BLE001
-                logger.warning("Failed to send failed update")
+                self.log.warning("Failed to send failed update")
 
             return f"Error writing file: {e}"
         else:
@@ -271,7 +264,7 @@ class ACPFileSystemProvider(ResourceProvider):
                 },
             )
         except Exception as e:  # noqa: BLE001
-            logger.warning("Failed to send pending update: %s", e)
+            self.log.warning("Failed to send pending update", error=e)
 
         try:  # Read current file content
             original_content = await self.session.requests.read_text_file(resolved_path)
@@ -288,7 +281,7 @@ class ACPFileSystemProvider(ResourceProvider):
                         raw_output=error_msg,
                     )
                 except Exception:  # noqa: BLE001
-                    logger.warning("Failed to send failed update")
+                    self.log.warning("Failed to send failed update")
                 return error_msg
 
             # Write the new content
@@ -315,7 +308,7 @@ class ACPFileSystemProvider(ResourceProvider):
                     raw_output=error_msg,
                 )
             except Exception:  # noqa: BLE001
-                logger.warning("Failed to send failed update")
+                self.log.warning("Failed to send failed update")
             return error_msg
         else:
             return success_msg
@@ -361,7 +354,7 @@ class ACPFileSystemProvider(ResourceProvider):
                 },
             )
         except Exception as e:  # noqa: BLE001
-            logger.warning("Failed to send pending update: %s", e)
+            self.log.warning("Failed to send pending update", error=e)
 
         try:
             if mode == "create":  # For create mode, don't read existing file
@@ -429,7 +422,7 @@ class ACPFileSystemProvider(ResourceProvider):
                                     changed_lines=progress_line_numbers,
                                 )
                         except Exception as e:  # noqa: BLE001
-                            logger.warning("Failed to send progress update: %s", e)
+                            self.log.warning("Failed to send progress update", error=e)
 
                 new_content = "".join(new_content_parts).strip()
 
@@ -442,7 +435,7 @@ class ACPFileSystemProvider(ResourceProvider):
                         raw_output=error_msg,
                     )
                 except Exception:  # noqa: BLE001
-                    logger.warning("Failed to send failed update")
+                    self.log.warning("Failed to send failed update")
                 return error_msg
 
             # Write the new content to file
@@ -480,7 +473,7 @@ class ACPFileSystemProvider(ResourceProvider):
                     raw_output=error_msg,
                 )
             except Exception:  # noqa: BLE001
-                logger.warning("Failed to send failed update")
+                self.log.warning("Failed to send failed update")
             return error_msg
         else:
             return success_msg
