@@ -8,19 +8,14 @@ from typing import TYPE_CHECKING, Any
 from pydantic_ai import RunContext  # noqa: TC002
 
 from acp.schema import TerminalToolCallContent
-from llmling_agent.log import get_logger
 from llmling_agent.resource_providers.base import ResourceProvider
 from llmling_agent.tools.base import Tool
 
 
 if TYPE_CHECKING:
-    from acp.schema import ClientCapabilities
     from llmling_agent_acp.session import ACPSession
 
 
-logger = get_logger(__name__)
-
-
 class ACPTerminalProvider(ResourceProvider):
     """Provides ACP terminal-related tools for command execution.
 
@@ -29,29 +24,26 @@ class ACPTerminalProvider(ResourceProvider):
     eliminating the need for parameter injection.
     """
 
-    def __init__(
-        self,
-        session: ACPSession,
-        client_capabilities: ClientCapabilities,
-        cwd: str | None = None,
-    ):
+    def __init__(self, session: ACPSession):
         """Initialize terminal provider.
 
         Args:
             session: Session for all tools created by this provider
-            client_capabilities: Client-reported capabilities
-            cwd: Current working directory for relative path resolution
         """
         super().__init__(name=f"acp_terminal_{session.session_id}")
         self.agent = session.acp_agent
         self.session_id = session.session_id
         self.session = session
-        self.client_capabilities = client_capabilities
-        self.cwd = cwd
+        self.client_capabilities = session.client_capabilities
+        self.cwd = session.cwd
 
     async def get_tools(self) -> list[Tool]:
         """Get all terminal tools with session_id baked in."""
-        if self.client_capabilities.terminal and self.agent.terminal_access:
+        if (
+            self.client_capabilities
+            and self.client_capabilities.terminal
+            and self.agent.terminal_access
+        ):
             return [
                 Tool.from_callable(
                     self.run_command, source="terminal", category="execute"
@@ -181,7 +173,7 @@ class ACPTerminalProvider(ResourceProvider):
                     title=f"Command failed: {e}",
                 )
             except Exception:  # noqa: BLE001
-                logger.warning("Failed to send error update")
+                self.log.warning("Failed to send error update")
 
             return f"Error executing command: {e}"
         else:
@@ -208,7 +200,7 @@ class ACPTerminalProvider(ResourceProvider):
                 kind="read",
             )
         except Exception as e:  # noqa: BLE001
-            logger.warning("Failed to send pending update: %s", e)
+            self.log.warning("Failed to send pending update", error=e)
 
         try:
             output_response = await self.session.requests.terminal_output(terminal_id)
@@ -250,7 +242,7 @@ Status: {status_text}"""
                     raw_output=f"Error: {e}",
                 )
             except Exception:  # noqa: BLE001
-                logger.warning("Failed to send failed update")
+                self.log.warning("Failed to send failed update")
             return f"Error getting command output: {e}"
         else:
             return result
@@ -292,7 +284,7 @@ Status: {status_text}"""
                 kind="execute",
             )
         except Exception as e:  # noqa: BLE001
-            logger.warning("Failed to send pending update: %s", e)
+            self.log.warning("Failed to send pending update", error=e)
 
         try:
             create_response = await self.session.requests.create_terminal(
@@ -319,7 +311,7 @@ Status: {status_text}"""
                     raw_output=f"Error: {e}",
                 )
             except Exception:  # noqa: BLE001
-                logger.warning("Failed to send failed update")
+                self.log.warning("Failed to send failed update")
             return f"Error creating terminal: {e}"
         else:
             return f"""Created terminal: {terminal_id}
@@ -356,7 +348,7 @@ Use this terminal_id with other terminal tools:
                 content=[TerminalToolCallContent(terminal_id=terminal_id)],
             )
         except Exception as e:  # noqa: BLE001
-            logger.warning("Failed to send pending update: %s", e)
+            self.log.warning("Failed to send pending update", error=e)
 
         try:
             exit_response = await self.session.requests.wait_for_terminal_exit(
@@ -389,7 +381,7 @@ Status: {"SUCCESS" if exit_code == 0 else "FAILED"}"""
                     raw_output=f"Error: {e}",
                 )
             except Exception:  # noqa: BLE001
-                logger.warning("Failed to send failed update")
+                self.log.warning("Failed to send failed update")
             return f"Error waiting for terminal exit: {e}"
         else:
             return result
@@ -430,7 +422,7 @@ Status: {"SUCCESS" if exit_code == 0 else "FAILED"}"""
                     raw_output=f"Error: {e}",
                 )
             except Exception:  # noqa: BLE001
-                logger.warning("Failed to send failed update")
+                self.log.warning("Failed to send failed update")
             return f"Error killing terminal: {e}"
         else:
             return f"Terminal {terminal_id} killed successfully"
@@ -457,7 +449,7 @@ Status: {"SUCCESS" if exit_code == 0 else "FAILED"}"""
                 kind="execute",
             )
         except Exception as e:  # noqa: BLE001
-            logger.warning("Failed to send pending update: %s", e)
+            self.log.warning("Failed to send pending update", error=e)
 
         try:
             await self.session.requests.release_terminal(terminal_id)
@@ -476,7 +468,7 @@ Status: {"SUCCESS" if exit_code == 0 else "FAILED"}"""
                     raw_output=f"Error: {e}",
                 )
             except Exception:  # noqa: BLE001
-                logger.warning("Failed to send failed update")
+                self.log.warning("Failed to send failed update")
             return f"Error releasing terminal: {e}"
         else:
             return f"Terminal {terminal_id} released successfully"
