@@ -15,18 +15,17 @@ import logfire
 
 from acp import AgentSideConnection
 from acp.stdio import stdio_streams
+from llmling_agent import AgentPool
 from llmling_agent.log import get_logger
 from llmling_agent.models.manifest import AgentsManifest
 from llmling_agent_acp.acp_agent import LLMlingACPAgent
 
 
 if TYPE_CHECKING:
-    from pathlib import Path
-
     from tokonomics.model_discovery import ProviderType
     from tokonomics.model_discovery.model_info import ModelInfo
+    from upath.types import JoinablePathLike
 
-    from llmling_agent import Agent, AgentPool
     from llmling_agent_providers.base import UsageLimits
 
 logger = get_logger(__name__)
@@ -70,6 +69,9 @@ class ACPServer:
     debug_commands: bool = False
     """Whether to enable debug slash commands for testing"""
 
+    agent: str | None = None
+    """Optional specific agent name to use (defaults to first agent)"""
+
     def __post_init__(self) -> None:
         """Initialize server configuration."""
         # Set default providers if None
@@ -81,9 +83,9 @@ class ACPServer:
         self._models_initialized = False
 
     @classmethod
-    async def from_config(
+    def from_config(
         cls,
-        config_path: str | Path,
+        config_path: JoinablePathLike,
         *,
         usage_limits: UsageLimits | None = None,
         session_support: bool = True,
@@ -93,6 +95,7 @@ class ACPServer:
         debug_messages: bool = False,
         debug_file: str | None = None,
         debug_commands: bool = False,
+        agent: str | None = None,
     ) -> Self:
         """Create ACP server from existing llmling-agent configuration.
 
@@ -106,13 +109,15 @@ class ACPServer:
             debug_messages: Enable saving JSON messages to file
             debug_file: Path to debug file
             debug_commands: Enable debug slash commands for testing
+            agent: Optional specific agent name to use (defaults to first agent)
 
         Returns:
             Configured ACP server instance with agent pool from config
         """
         manifest = AgentsManifest.from_file(config_path)
+        pool = AgentPool(manifest=manifest)
         server = cls(
-            agent_pool=manifest.pool,
+            agent_pool=pool,
             usage_limits=usage_limits,
             session_support=session_support,
             file_access=file_access,
@@ -121,14 +126,22 @@ class ACPServer:
             debug_messages=debug_messages,
             debug_file=debug_file,
             debug_commands=debug_commands,
+            agent=agent,
         )
         agent_names = list(server.agent_pool.agents.keys())
-        logger.info("Created ACP server with agent pool containing: %s", agent_names)
-        return server
 
-    def get_agent(self, name: str) -> Agent[Any]:
-        """Get agent by name from the pool."""
-        return self.agent_pool.get_agent(name)
+        # Validate specified agent exists if provided
+        if agent and agent not in agent_names:
+            msg = (
+                f"Specified agent {agent!r} not found in config. "
+                f"Available agents: {agent_names}"
+            )
+            raise ValueError(msg)
+
+        logger.info("Created ACP server with agent pool containing: %s", agent_names)
+        if agent:
+            logger.info("Will use agent '%s' for ACP sessions", agent)
+        return server
 
     async def run(self) -> None:
         """Run the ACP server."""
@@ -136,13 +149,11 @@ class ACPServer:
             msg = "Server is already running"
             raise RuntimeError(msg)
         self._running = True
-
+        agent_names = list(self.agent_pool.agents.keys())
+        msg = "Starting ACP server with %d agents on stdio: %s"
+        logger.info(msg, len(agent_names), agent_names)
         try:
             await self._initialize_models()  # Initialize models on first run
-            agent_names = list(self.agent_pool.agents.keys())
-            msg = "Starting ACP server with %d agents on stdio: %s"
-            logger.info(msg, len(agent_names), agent_names)
-
             create_acp_agent = functools.partial(
                 LLMlingACPAgent,
                 agent_pool=self.agent_pool,
@@ -152,8 +163,8 @@ class ACPServer:
                 terminal_access=self.terminal_access,
                 usage_limits=self.usage_limits,
                 debug_commands=self.debug_commands,
+                default_agent=self.agent,
             )
-
             reader, writer = await stdio_streams()
             file = self.debug_file if self.debug_messages else None
             conn = AgentSideConnection(create_acp_agent, writer, reader, debug_file=file)
@@ -185,24 +196,8 @@ class ACPServer:
             raise RuntimeError(msg)
 
         self._running = False
-        logger.info("Shutting down ACP server")
-
-        try:
-            await self.agent_pool.__aexit__(None, None, None)
-        except Exception as e:  # noqa: BLE001
-            logger.warning("Failed to cleanup agent pool: %s", e)
-
         logger.info("ACP server shutdown complete")
 
-    async def __aenter__(self) -> Self:
-        """Async context manager entry."""
-        await self.agent_pool.__aenter__()
-        return self
-
-    async def __aexit__(self, *exc: object) -> None:
-        """Async context manager exit."""
-        await self.shutdown()
-
     @logfire.instrument("ACP: Initializing models.")
     async def _initialize_models(self) -> None:
         """Initialize available models using tokonomics model discovery."""
