@@ -14,13 +14,10 @@ if TYPE_CHECKING:
     from collections.abc import Sequence
 
     from acp import Client
-    from acp.acp_types import MCPServer
-    from acp.schema import ClientCapabilities
+    from acp.schema import ClientCapabilities, McpServer
     from llmling_agent import AgentPool
     from llmling_agent_acp.acp_agent import LLMlingACPAgent
     from llmling_agent_acp.command_bridge import ACPCommandBridge
-
-    # from llmling_agent_acp.permission_server import PermissionMCPServer
     from llmling_agent_providers.base import UsageLimits
 
 
@@ -61,7 +58,7 @@ class ACPSessionManager:
         cwd: str,
         client: Client,  # This is the AgentSideConnection
         acp_agent: LLMlingACPAgent,
-        mcp_servers: Sequence[MCPServer] | None = None,
+        mcp_servers: Sequence[McpServer] | None = None,
         session_id: str | None = None,
         usage_limits: UsageLimits | None = None,
         client_capabilities: ClientCapabilities | None = None,
@@ -104,18 +101,17 @@ class ACPSessionManager:
                 command_bridge=self.command_bridge,
                 acp_agent=acp_agent,
                 client_capabilities=client_capabilities,
+                manager=self,
             )
 
             # Initialize MCP servers if any are provided
+            #  TODO: perhaps move to ACPAgent.new_session?
             await session.initialize_mcp_servers()
 
-            # Initialize project context from AGENTS.md
-            await session.initialize_project_context()
-
             self._sessions[session_id] = session
             return session_id  # Commands will be sent after session response is returned
 
-    async def get_session(self, session_id: str) -> ACPSession | None:
+    def get_session(self, session_id: str) -> ACPSession | None:
         """Get an existing session by ID.
 
         Args:
@@ -140,37 +136,6 @@ class ACPSessionManager:
             else:
                 logger.warning("Attempted to close non-existent session %s", session_id)
 
-    async def list_sessions(self) -> list[str]:
-        """List all active session IDs.
-
-        Returns:
-            List of active session IDs
-        """
-        return list(self._sessions.keys())
-
-    async def get_session_count(self) -> int:
-        """Get the number of active sessions.
-
-        Returns:
-            Number of active sessions
-        """
-        return len(self._sessions)
-
-    async def close_all_sessions(self) -> None:
-        """Close all active sessions."""
-        async with self._lock:
-            sessions = list(self._sessions.values())
-            self._sessions.clear()
-
-        # Close sessions outside of lock to avoid deadlock
-        for session in sessions:
-            try:
-                await session.close()
-            except Exception:
-                logger.exception("Error closing session %s", session.session_id)
-
-        logger.info("Closed all %d sessions", len(sessions))
-
     async def cleanup_inactive_sessions(self) -> None:
         """Remove any inactive sessions."""
         async with self._lock:
@@ -197,7 +162,18 @@ class ACPSessionManager:
 
     async def __aexit__(self, *exc: object):
         """Async context manager exit."""
-        await self.close_all_sessions()
+        async with self._lock:
+            sessions = list(self._sessions.values())
+            self._sessions.clear()
+
+        # Close sessions outside of lock to avoid deadlock
+        for session in sessions:
+            try:
+                await session.close()
+            except Exception:
+                logger.exception("Error closing session %s", session.session_id)
+
+        logger.info("Closed all %d sessions", len(sessions))
 
     def _on_commands_updated(self) -> None:
         """Handle command updates by notifying all active sessions."""
