@@ -15,7 +15,7 @@ from acp import (
     NewSessionResponse,
     PromptResponse,
 )
-from acp.schema import ClientCapabilities, FileSystemCapability
+from acp.schema import ClientCapabilities, FileSystemCapability, Implementation
 from llmling_agent_acp.acp_agent import LLMlingACPAgent
 
 
@@ -42,6 +42,7 @@ class TestAgent(Agent):
         return InitializeResponse(
             protocol_version=params.protocol_version,
             agent_capabilities=None,
+            agent_info=Implementation(name="test-agent", version="1.0"),
         )
 
     async def new_session(self, params: NewSessionRequest) -> NewSessionResponse:
@@ -102,7 +103,7 @@ def mock_agent_pool():
     def simple_callback(message: str) -> str:
         return f"Test response: {message}"
 
-    agent = Agent[None](name="test_agent", provider=simple_callback)
+    agent = Agent(name="test_agent", provider=simple_callback)
     pool = AgentPool[None]()
     pool.register("test_agent", agent)
     return pool
