@@ -3,11 +3,11 @@
 from __future__ import annotations
 
 import sys
+import tempfile
 
 import pytest
 from slashed import CommandStore
 
-from acp import DefaultACPClient
 from acp.schema import EnvVariable, StdioMcpServer
 from llmling_agent import Agent
 from llmling_agent.delegation import AgentPool
@@ -41,16 +41,15 @@ async def test_mcp_server_conversion():
 
 
 @pytest.mark.skipif(sys.platform == "darwin", reason="macOS subprocess handling differs")
-async def test_session_with_mcp_servers(mock_acp_agent, client_capabilities):
+async def test_session_with_mcp_servers(test_client, mock_acp_agent, client_capabilities):
     """Test creating an ACP session with MCP servers."""
 
     def simple_callback(message: str) -> str:
         return f"Test response for: {message}"
 
-    agent = Agent[None](name="test_agent", provider=simple_callback)
+    agent = Agent(name="test_agent", provider=simple_callback)
     agent_pool = AgentPool[None]()
     agent_pool.register("test_agent", agent)
-    client = DefaultACPClient(allow_file_operations=True)
     command_store = CommandStore()
     command_bridge = ACPCommandBridge(command_store)
 
@@ -58,14 +57,14 @@ async def test_session_with_mcp_servers(mock_acp_agent, client_capabilities):
     mcp_servers = [
         StdioMcpServer(
             name="filesystem",
-            command="echo",  # Use echo as a dummy command
-            args=["filesystem server"],
+            command="npx",  # Use echo as a dummy command
+            args=["-y", "@upstash/context7-mcp"],
             env=[],
         ),
         StdioMcpServer(
             name="web_search",
-            command="echo",  # Use echo as a dummy command
-            args=["web search server"],
+            command="uvx",  # Use echo as a dummy command
+            args=["mcp-server-git"],
             env=[EnvVariable(name="API_KEY", value="dummy")],
         ),
     ]
@@ -74,8 +73,8 @@ async def test_session_with_mcp_servers(mock_acp_agent, client_capabilities):
         session_id="test_session",
         agent_pool=agent_pool,
         current_agent_name="test_agent",
-        cwd="/tmp",
-        client=client,
+        cwd=tempfile.gettempdir(),
+        client=test_client,
         mcp_servers=mcp_servers,
         command_bridge=command_bridge,
         acp_agent=mock_acp_agent,
@@ -97,7 +96,7 @@ async def test_session_with_mcp_servers(mock_acp_agent, client_capabilities):
 
 
 @pytest.mark.skipif(sys.platform == "darwin", reason="macOS subprocess handling differs")
-async def test_session_manager_with_mcp(mock_acp_agent, client_capabilities):
+async def test_session_manager_with_mcp(test_client, mock_acp_agent, client_capabilities):
     """Test session manager creating sessions with MCP servers."""
     command_store = CommandStore()
     command_bridge = ACPCommandBridge(command_store)
@@ -106,24 +105,23 @@ async def test_session_manager_with_mcp(mock_acp_agent, client_capabilities):
     def simple_callback(message: str) -> str:
         return f"Test response for: {message}"
 
-    agent = Agent[None](name="test_agent", provider=simple_callback)
+    agent = Agent(name="test_agent", provider=simple_callback)
     agent_pool = AgentPool[None]()  # Create empty pool and register the agent
     agent_pool.register("test_agent", agent)
-    client = DefaultACPClient()
     mcp_servers = [StdioMcpServer(name="tools", command="echo", args=["tools"], env=[])]
 
     try:
         session_id = await session_manager.create_session(
             agent_pool=agent_pool,
             default_agent_name="test_agent",
-            cwd="/tmp",
-            client=client,
+            cwd=tempfile.gettempdir(),
+            client=test_client,
             mcp_servers=mcp_servers,
             acp_agent=mock_acp_agent,
             client_capabilities=client_capabilities,
         )
 
-        session = await session_manager.get_session(session_id)
+        session = session_manager.get_session(session_id)
         assert session is not None
         assert session.mcp_servers == mcp_servers
         await session_manager.close_session(session_id)
@@ -139,7 +137,7 @@ async def test_tool_integration():
     def simple_callback(message: str) -> str:
         return f"Test response for: {message}"
 
-    agent = Agent[None](name="test_agent", provider=simple_callback)
+    agent = Agent(name="test_agent", provider=simple_callback)
 
     async with agent:
         initial_tools = len(await agent.tools.get_tools())
