@@ -3,9 +3,9 @@
 from __future__ import annotations
 
 import os
-from typing import TYPE_CHECKING, Annotated, Literal
+from typing import TYPE_CHECKING, Annotated, Literal, Self
 
-from pydantic import Field
+from pydantic import Field, HttpUrl
 from schemez import Schema
 
 
@@ -47,7 +47,7 @@ class BaseMCPServerConfig(Schema):
     env: dict[str, str] | None = None
     """Environment variables to pass to the server process."""
 
-    timeout: float = 30.0
+    timeout: float = Field(default=60.0, gt=0)
     """Timeout for the server process in seconds."""
 
     def get_env_vars(self) -> dict[str, str]:
@@ -58,6 +58,21 @@ class BaseMCPServerConfig(Schema):
         env["PYTHONIOENCODING"] = "utf-8"
         return env
 
+    @property
+    def client_id(self) -> str:
+        """Generate a unique client ID for this server configuration."""
+        raise NotImplementedError
+
+    @classmethod
+    def from_string(cls, text: str) -> MCPServerConfig:
+        """Create a MCPServerConfig from a string."""
+        text = text.strip()
+        if text.startswith(("http://", "https://")) and text.endswith("/sse"):
+            return SSEMCPServerConfig(url=HttpUrl(text))
+        if text.startswith(("http://", "https://")):
+            return StreamableHTTPMCPServerConfig(url=HttpUrl(text))
+        return StdioMCPServerConfig.from_string(text)
+
 
 class StdioMCPServerConfig(BaseMCPServerConfig):
     """MCP server started via stdio.
@@ -75,10 +90,17 @@ class StdioMCPServerConfig(BaseMCPServerConfig):
     """Command arguments (e.g. ["run", "some-server", "--debug"])."""
 
     @classmethod
-    def from_string(cls, command: str) -> StdioMCPServerConfig:
+    def from_string(cls, command: str) -> Self:
         """Create a MCP server from a command string."""
-        cmd, args = command.split(maxsplit=1)
-        return cls(command=cmd, args=args.split())
+        parts = command.split(maxsplit=1)
+        cmd = parts[0]
+        args = parts[1].split() if len(parts) > 1 else []
+        return cls(command=cmd, args=args)
+
+    @property
+    def client_id(self) -> str:
+        """Generate a unique client ID for this stdio server configuration."""
+        return f"{self.command}_{' '.join(self.args)}"
 
     async def check(self) -> ServerScoreCard:
         from mcp_interviewer import MCPInterviewer
@@ -98,7 +120,7 @@ class SSEMCPServerConfig(BaseMCPServerConfig):
     type: Literal["sse"] = Field("sse", init=False)
     """SSE server configuration."""
 
-    url: str
+    url: HttpUrl
     """URL of the SSE server endpoint."""
 
     headers: dict[str, str] | None = None
@@ -107,12 +129,17 @@ class SSEMCPServerConfig(BaseMCPServerConfig):
     auth: MCPServerAuthSettings = Field(default_factory=MCPServerAuthSettings)
     """OAuth settings for the SSE server."""
 
+    @property
+    def client_id(self) -> str:
+        """Generate a unique client ID for this SSE server configuration."""
+        return f"sse_{self.url}"
+
     async def check(self) -> ServerScoreCard:
         from mcp_interviewer import MCPInterviewer
         from mcp_interviewer.models import SseServerParameters
 
         params = SseServerParameters(
-            url=self.url,
+            url=str(self.url),
             timeout=self.timeout,
             headers=self.headers,
         )
@@ -129,7 +156,7 @@ class StreamableHTTPMCPServerConfig(BaseMCPServerConfig):
     type: Literal["streamable-http"] = Field("streamable-http", init=False)
     """HTTP server configuration."""
 
-    url: str
+    url: HttpUrl
     """URL of the HTTP server endpoint."""
 
     headers: dict[str, str] | None = None
@@ -138,12 +165,17 @@ class StreamableHTTPMCPServerConfig(BaseMCPServerConfig):
     auth: MCPServerAuthSettings = Field(default_factory=MCPServerAuthSettings)
     """OAuth settings for the HTTP server."""
 
+    @property
+    def client_id(self) -> str:
+        """Generate a unique client ID for this streamable HTTP server configuration."""
+        return f"streamable_http_{self.url}"
+
     async def check(self) -> ServerScoreCard:
         from mcp_interviewer import MCPInterviewer
         from mcp_interviewer.models import StreamableHttpServerParameters
 
         params = StreamableHttpServerParameters(
-            url=self.url,
+            url=str(self.url),
             timeout=self.timeout,
             headers=self.headers,
         )
