@@ -1,3 +1,5 @@
+"""Utils for documentation."""
+
 from __future__ import annotations
 
 import ast
@@ -7,11 +9,10 @@ from typing import Literal
 import mknodes as mk
 
 
-def create_example_doc(
-    name: str,
-    *,
-    style: Literal["simple", "full"] = "full",
-) -> mk.MkContainer:
+DocStyle = Literal["simple", "full"]
+
+
+def create_example_doc(name: str, *, style: DocStyle = "full") -> mk.MkContainer:
     """Create documentation for an example file.
 
     Args:
@@ -25,7 +26,6 @@ def create_example_doc(
         Container with all documentation elements
     """
     path = Path("src/llmling_agent_examples") / name
-
     if not path.exists():
         msg = f"Example {name} not found"
         raise FileNotFoundError(msg)
@@ -38,10 +38,9 @@ def create_example_doc(
         container += mk.MkHeader(title, level=2)
 
         # Add description from docstring if available
-        if docstring := ast.get_docstring(ast.parse(path.read_text())):
+        if docstring := ast.get_docstring(ast.parse(path.read_text(encoding="utf-8"))):
             container += docstring
 
     # Add the code itself
-    container += mk.MkCode(path.read_text(), language="python")
-
+    container += mk.MkCode(path.read_text(encoding="utf-8"), language="python")
     return container
