@@ -28,7 +28,7 @@ async def main():
     )
 
     # Create agent with MCP server
-    agent = Agent[None](
+    agent = Agent(
         name="demo_agent",
         model="openai:gpt-5-nano",
         system_prompt="You are a helpful assistant with code fixing tools.",
@@ -36,8 +36,6 @@ async def main():
     )
 
     async with agent:
-        print(f"📋 Agent created with tools: {list(agent.tools.keys())}")
-
         # Code with actual bugs
         buggy_code = 'prin("hello world"'
 
