@@ -7,7 +7,11 @@ from collections import defaultdict
 from typing import TYPE_CHECKING, Any, Self
 
 from fastmcp import FastMCP
-from mcp.server.lowlevel.server import NotificationOptions
+from fastmcp.server.middleware.caching import ResponseCachingMiddleware
+from key_value.aio.stores.disk import DiskStore
+from mcp import CreateMessageResult
+from mcp.types import TextContent
+import platformdirs
 
 import llmling_agent
 from llmling_agent.utils.tasks import TaskManager
@@ -19,8 +23,11 @@ if TYPE_CHECKING:
     from collections.abc import Callable
     from contextlib import AbstractAsyncContextManager
 
+    from fastmcp import SamplingMessage, ServerSession
     import mcp
     from mcp.server.lowlevel.server import LifespanResultT
+    from mcp.shared.context import LifespanContextT, RequestContext
+    from mcp.types import CreateMessageRequestParams as SamplingParams
 
     from llmling_agent.resource_providers.base import ResourceProvider
     from llmling_agent_config.pool_server import MCPPoolServerConfig
@@ -33,6 +40,12 @@ if TYPE_CHECKING:
 logger = get_logger(__name__)
 
 
+llmling_dir = platformdirs.user_config_dir("llmling-agent")
+
+store = DiskStore(directory=llmling_dir)
+middleware = ResponseCachingMiddleware(cache_storage=store)
+
+
 class LLMLingServer:
     """MCP protocol server implementation."""
 
@@ -72,20 +85,25 @@ class LLMLingServer:
             instructions=instructions,
             lifespan=lifespan,
             version=llmling_agent.__version__,
+            middleware=[middleware],
+            # sampling_handler=self._sampling_handler,
         )
         self.server = self.fastmcp._mcp_server
-        self.server.notification_options = NotificationOptions(
-            prompts_changed=True,
-            resources_changed=True,
-            tools_changed=True,
-        )
-
-        self._setup_handlers()
-
-    def _setup_handlers(self):
-        """Register MCP protocol handlers."""
         register_handlers(self)
 
+    async def _sampling_handler(
+        self,
+        messages: list[SamplingMessage],
+        params: SamplingParams,
+        context: RequestContext[ServerSession, LifespanContextT],
+    ) -> CreateMessageResult:
+        # This is a fallback handler in case the client does not support sampling.
+        return CreateMessageResult(
+            role="user",
+            content=[TextContent(type="text", text="test")],
+            model="test",
+        )
+
     async def start(self, *, raise_exceptions: bool = False):
         """Start the server."""
         try:
@@ -103,10 +121,9 @@ class LLMLingServer:
     async def shutdown(self):
         """Shutdown the server."""
         try:
-            if self._tasks:
-                for task in self._tasks:
-                    task.cancel()
-                await asyncio.gather(*self._tasks, return_exceptions=True)
+            for task in self._tasks:
+                task.cancel()
+            await asyncio.gather(*self._tasks, return_exceptions=True)
         finally:
             self._tasks.clear()
 
