@@ -22,7 +22,7 @@ if TYPE_CHECKING:
     from llmling_agent_config.providers import ProcessorCallback
     from llmling_agent_providers.base import UsageLimits
 
-from pydantic_ai.messages import PartDeltaEvent, TextPartDelta
+from pydantic_ai import PartDeltaEvent, TextPartDelta
 
 from llmling_agent.agent.agent import StreamCompleteEvent
 
@@ -57,7 +57,7 @@ class CallbackProvider(AgentProvider[None]):
         *prompts: str | Content,
         message_history: list[ChatMessage],
         message_id: str,
-        result_type: type[TResult] | None = None,
+        output_type: type[TResult] | None = None,
         system_prompt: str | None = None,
         usage_limits: UsageLimits | None = None,
         **kwargs: Any,
@@ -93,14 +93,18 @@ class CallbackProvider(AgentProvider[None]):
         *prompts: str | Content,
         message_id: str,
         message_history: list[ChatMessage],
-        result_type: type[Any] | None = None,
+        output_type: type[Any] | None = None,
         system_prompt: str | None = None,
         usage_limits: UsageLimits | None = None,
         **kwargs: Any,
     ) -> AsyncIterator[Any]:
         """Stream response events - simulate streaming by yielding complete result."""
-        from pydantic_ai.messages import PartStartEvent, TextPart
-        from pydantic_ai.run import AgentRunResult, AgentRunResultEvent
+        from pydantic_ai import (
+            AgentRunResult,
+            AgentRunResultEvent,
+            PartStartEvent,
+            TextPart,
+        )
 
         try:
             # Emit start event
@@ -130,7 +134,7 @@ if __name__ == "__main__":
         from llmling_agent.agent.agent import Agent
 
         provider = CallbackProvider(str.upper, name="uppercase")
-        uppercase = Agent[Any](provider=provider)
+        uppercase = Agent(provider=provider)
 
         # Normal usage
         result = await uppercase.run("hello")
