@@ -9,20 +9,20 @@ from typing import TYPE_CHECKING, Any, get_args, get_origin
 
 from llmling_models import AllModels, infer_model
 import logfire
-from pydantic_ai import Agent as PydanticAgent
-import pydantic_ai._function_schema
-from pydantic_ai.messages import (
+from pydantic_ai import (
+    Agent as PydanticAgent,
     FunctionToolCallEvent,
     PartStartEvent,
+    RunContext,
     TextPartDelta,
     ToolCallPart,
+    UsageLimits as PydanticAiUsageLimits,
 )
-from pydantic_ai.models import KnownModelName
-from pydantic_ai.tools import GenerateToolJsonSchema, RunContext
-from pydantic_ai.usage import UsageLimits as PydanticAiUsageLimits
+import pydantic_ai._function_schema
+from pydantic_ai.models import KnownModelName, Model
+from pydantic_ai.tools import GenerateToolJsonSchema
 
 from llmling_agent.agent.context import AgentContext
-from llmling_agent.common_types import ModelProtocol
 from llmling_agent.log import get_logger
 from llmling_agent.messaging.messages import TokenCost, TokenUsage
 from llmling_agent.tasks.exceptions import (
@@ -40,13 +40,13 @@ from llmling_agent_providers.pydanticai.utils import (
 
 
 if TYPE_CHECKING:
-    from collections.abc import AsyncIterator, Awaitable, Callable
+    from collections.abc import AsyncIterable, AsyncIterator, Awaitable, Callable
 
-    from pydantic_ai import AgentStreamEvent
-    from pydantic_ai.agent import AgentRunResult
-    from pydantic_ai.run import AgentRunResultEvent
+    from anyenv import MultiEventHandler
+    from pydantic_ai import AgentRunResultEvent, AgentStreamEvent, BuiltinToolCallPart
+    from pydantic_ai.agent import AgentRunResult, EventStreamHandler
 
-    from llmling_agent.common_types import EndStrategy, ModelType
+    from llmling_agent.common_types import EndStrategy, IndividualEventHandler, ModelType
     from llmling_agent.messaging.messages import ChatMessage
     from llmling_agent.models.content import Content
     from llmling_agent.tools.base import Tool
@@ -92,7 +92,7 @@ class PydanticAIProvider(AgentProvider[Any]):
     def __init__(
         self,
         *,
-        model: str | ModelProtocol | None = None,
+        model: str | Model | None = None,
         context: AgentContext | None = None,
         name: str = "agent",
         retries: int = 1,
@@ -196,8 +196,8 @@ class PydanticAIProvider(AgentProvider[Any]):
 
             async def wrapped(ctx: RunContext[AgentContext], *args, **kwargs):  # pyright: ignore
                 result = await agent_ctx.handle_confirmation(tool, kwargs)
-                if agent_ctx.report_progress:
-                    await agent_ctx.report_progress(ctx.run_step, None)
+                # if agent_ctx.report_progress:
+                #     await agent_ctx.report_progress(ctx.run_step, None)
                 match result:
                     case "allow":
                         return await execute(original_tool, ctx, *args, **kwargs)
@@ -250,96 +250,97 @@ class PydanticAIProvider(AgentProvider[Any]):
         wrapped.__name__ = tool.name
         return wrapped
 
-    @logfire.instrument("Pydantic-AI call. model: {model} result type {result_type}.")
+    @logfire.instrument("Pydantic-AI call. model: {model} result type {output_type}.")
     async def generate_response(
         self,
         *prompts: str | Content,
         message_id: str,
         message_history: list[ChatMessage],
-        result_type: type[Any] | None = None,
+        output_type: type[Any] | None = None,
         model: ModelType = None,
         tools: list[Tool] | None = None,
         system_prompt: str | None = None,
         usage_limits: UsageLimits | None = None,
+        event_stream_handler: MultiEventHandler[IndividualEventHandler] | None = None,
         **kwargs: Any,
     ) -> ProviderResponse:
         """Generate response using pydantic-ai."""
         agent = await self.get_agent(system_prompt or "", tools=tools or [])
-        use_model = model or self.model
-        if isinstance(use_model, str):
-            use_model = infer_model(use_model)
-            self.model_changed.emit(use_model)
-
-        # Create event stream handler for real-time tool signals
         tool_dict = {i.name: i for i in tools or []}
 
-        async def event_stream_handler(ctx, events):
+        # Create event stream handler for real-time tool signals
+        async def internal_tool_handler(ctx: RunContext, event: AgentStreamEvent):
+            if isinstance(event, FunctionToolCallEvent):
+                # Extract tool call info and emit signal immediately
+                call = event.part
+                if call.tool_name in tool_dict:
+                    tool_call_info = self._create_tool_call_info(
+                        call, tool_dict, message_id
+                    )
+                    tool_call_info.message_id = message_id
+
+                    self.tool_used.emit(tool_call_info)
+
+        # Event distributor: single consumer, multiple processors
+        async def event_distributor(
+            ctx: RunContext, events: AsyncIterable[AgentStreamEvent]
+        ):
+            # Collect all handlers
+            all_handlers: list[IndividualEventHandler] = [internal_tool_handler]
+            if event_stream_handler:
+                all_handlers.extend(event_stream_handler._wrapped_handlers)
+
+            # Single consumer distributes events to all handlers
             async for event in events:
-                if isinstance(event, FunctionToolCallEvent):
-                    # Extract tool call info and emit signal immediately
-                    call = event.part
-                    if call.tool_name in tool_dict:
-                        tool_call_info = self._create_tool_call_info(
-                            call, tool_dict, message_id
-                        )
-                        tool_call_info.message_id = message_id
-                        tool_call_info.context_data = (
-                            self._context.data if self._context else None
-                        )
+                # Execute all handlers for this event
+                for handler in all_handlers:
+                    await handler(ctx, event)
 
-                        self.tool_used.emit(tool_call_info)
+        # Always use our event distributor as the final handler
+        final_handler: EventStreamHandler = event_distributor
 
-        try:
-            # Convert prompts to pydantic-ai format
-            converted_prompts = await convert_prompts_to_user_content(prompts)
+        # Convert prompts to pydantic-ai format
+        converted_prompts = await convert_prompts_to_user_content(prompts)
 
-            # Run with complete history and event handler
-            to_use = model or self.model
-            to_use = infer_model(to_use) if isinstance(to_use, str) else to_use
-            limits = asdict(usage_limits) if usage_limits else {}
-            result: AgentRunResult = await agent.run(
-                converted_prompts,  # Pass converted prompts
-                deps=self._context,  # type: ignore
-                message_history=[to_model_request(m) for m in message_history],
-                model=to_use,  # type: ignore
-                output_type=result_type or str,
-                model_settings=self.model_settings,  # type: ignore
-                usage_limits=PydanticAiUsageLimits(**limits),
-                event_stream_handler=event_stream_handler,
-            )
+        # Run with complete history and event handler
+        to_use = model or self.model
+        to_use = infer_model(to_use) if isinstance(to_use, str) else to_use
+        limits = asdict(usage_limits) if usage_limits else {}
+        result: AgentRunResult = await agent.run(
+            converted_prompts,  # Pass converted prompts
+            deps=self._context,  # type: ignore
+            message_history=[to_model_request(m) for m in message_history],
+            model=to_use,
+            output_type=output_type or str,
+            model_settings=self.model_settings,  # type: ignore
+            usage_limits=PydanticAiUsageLimits(**limits),
+            event_stream_handler=final_handler,
+        )
 
-            # Extract tool calls for final response
-            # (signals already emitted via event handler)
-            new_msgs = result.new_messages()
-            tool_calls = get_tool_calls(new_msgs, tool_dict, agent_name=self.name)
-            for call in tool_calls:
-                call.message_id = message_id
-                call.context_data = self._context.data if self._context else None
+        # Extract tool calls for final response
+        # (signals already emitted via event handler)
+        new_msgs = result.new_messages()
+        tool_calls = get_tool_calls(new_msgs, tool_dict, agent_name=self.name)
+        for call in tool_calls:
+            call.message_id = message_id
 
-            # Get the actual model name from pydantic-ai response
-            resolved_model = result.response.model_name or ""
-            usage = result.usage()
-            cost = await TokenCost.from_usage(model=resolved_model, usage=usage)
-            total = cost.total_cost if cost else Decimal(0)
-            token_usage = TokenUsage(
-                total=usage.total_tokens,
-                prompt=usage.input_tokens,
-                completion=usage.output_tokens,
-            )
-            cost_info = TokenCost(token_usage=token_usage, total_cost=total)
-            return ProviderResponse(
-                content=result.output,
-                tool_calls=tool_calls,
-                cost_and_usage=cost_info,
-                model_name=resolved_model,
-            )
-        finally:
-            # Restore original model in signal if we had an override
-            if model:
-                original = self.model
-                if isinstance(original, str):
-                    original = infer_model(original)
-                self.model_changed.emit(original)
+        # Get the actual model name from pydantic-ai response
+        resolved_model = result.response.model_name or ""
+        usage = result.usage()
+        cost = await TokenCost.from_usage(model=resolved_model, usage=usage)
+        total = cost.total_cost if cost else Decimal(0)
+        token_usage = TokenUsage(
+            total=usage.total_tokens,
+            prompt=usage.input_tokens,
+            completion=usage.output_tokens,
+        )
+        cost_info = TokenCost(token_usage=token_usage, total_cost=total)
+        return ProviderResponse(
+            content=result.output,
+            response=result.response,
+            tool_calls=tool_calls,
+            cost_and_usage=cost_info,
+        )
 
     @property
     def name(self) -> str:
@@ -356,16 +357,12 @@ class PydanticAIProvider(AgentProvider[Any]):
 
         Args:
             model: New model to use (name or instance)
-
-        Emits:
-            model_changed signal with the new model
         """
         old_name = self.model_name
         if isinstance(model, str):
             model = infer_model(model)
         self._model = model
         self._kwargs["model"] = model
-        self.model_changed.emit(model)
         logger.debug("Changed model from %s to %s", old_name, self.model_name)
 
     @property
@@ -374,14 +371,17 @@ class PydanticAIProvider(AgentProvider[Any]):
         match model := self._kwargs["model"]:
             case str() | None:
                 return model
-            case ModelProtocol():
+            case Model():
                 return model.model_name
             case _:
                 msg = f"Invalid model type: {model}"
                 raise ValueError(msg)
 
     def _create_tool_call_info(
-        self, tool_part: ToolCallPart, tool_dict: dict, message_id: str
+        self,
+        tool_part: ToolCallPart | BuiltinToolCallPart,
+        tool_dict: dict,
+        message_id: str,
     ):
         """Create ToolCallInfo from tool call part."""
         from llmling_agent.tools.tool_call_info import ToolCallInfo
@@ -393,21 +393,20 @@ class PydanticAIProvider(AgentProvider[Any]):
             agent_name=self.name,
             tool_call_id=tool_part.tool_call_id,
             message_id=message_id,
-            context_data=self._context.data if self._context else None,
         )
 
-    async def stream_events(
+    async def stream_events[TResult = str](
         self,
         *prompts: str | Content,
         message_history: list[ChatMessage],
         message_id: str,
-        result_type: type[Any] | None = None,
+        output_type: type[TResult] | None = None,
         model: ModelType = None,
         tools: list[Tool] | None = None,
         system_prompt: str | None = None,
         usage_limits: UsageLimits | None = None,
         **kwargs: Any,
-    ) -> AsyncIterator[AgentStreamEvent | AgentRunResultEvent]:
+    ) -> AsyncIterator[AgentStreamEvent | AgentRunResultEvent[TResult]]:
         """Stream events directly from pydantic-ai without wrapper complexity."""
         agent = await self.get_agent(system_prompt or "", tools=tools or [])
         use_model = model or self.model
@@ -415,23 +414,14 @@ class PydanticAIProvider(AgentProvider[Any]):
         if isinstance(use_model, str):
             use_model = infer_model(use_model)
 
-        if model:
-            self.model_changed.emit(use_model)
-
-        # Convert prompts to pydantic-ai format
         converted_prompts = await convert_prompts_to_user_content(prompts)
-        # Convert all messages to pydantic-ai format
-        model_messages = [to_model_request(m) for m in message_history]
-
         tool_dict = {i.name: i for i in tools or []}
-
-        # Stream events directly from pydantic-ai
         async for event in agent.run_stream_events(
             converted_prompts,
             deps=self._context,
-            message_history=model_messages,
+            message_history=[to_model_request(m) for m in message_history],
             model=model or self.model,  # type: ignore
-            output_type=result_type or str,
+            output_type=output_type or str,
             model_settings=self.model_settings,  # type: ignore
             usage_limits=PydanticAiUsageLimits(**limits),
         ):
@@ -447,13 +437,6 @@ class PydanticAIProvider(AgentProvider[Any]):
                     self.tool_used.emit(call_info)
             yield event
 
-        # Reset model signal if needed
-        if model:
-            original = self.model
-            if isinstance(original, str):
-                original = infer_model(original)
-            self.model_changed.emit(original)
-
 
 if __name__ == "__main__":
     import asyncio
@@ -482,10 +465,10 @@ if __name__ == "__main__":
             match event:
                 case PartDeltaEvent(delta=TextPartDelta(content_delta=delta)):
                     chunks.append(delta)
-                    print(f"Text chunk: '{delta}'")
+                    print(f"Text chunk: {delta!r}")
                 case PartDeltaEvent(delta=ToolCallPartDelta(content_delta=delta)):
                     chunks.append(delta)
-                    print(f"Tool call chunk: '{delta}'")
+                    print(f"Tool call chunk: {delta!r}")
                 case AgentRunResultEvent(result=result):
                     final_result = result
                     print(f"Final result: {result}")
