@@ -15,9 +15,10 @@ if TYPE_CHECKING:
     from datetime import datetime
     from types import TracebackType
 
+    from pydantic_ai import FinishReason
+
     from llmling_agent.common_types import JsonValue
     from llmling_agent.messaging.messages import ChatMessage, TokenCost
-    from llmling_agent.tools import ToolCallInfo
     from llmling_agent_config.session import SessionQuery
     from llmling_agent_config.storage import BaseStorageProviderConfig
     from llmling_agent_storage.models import ConversationData, QueryFilters, StatsFilters
@@ -61,7 +62,6 @@ class StorageProvider[T]:
         self.task_manager = TaskManager()
         self.log_messages = config.log_messages
         self.log_conversations = config.log_conversations
-        self.log_tool_calls = config.log_tool_calls
         self.log_commands = config.log_commands
         self.log_context = config.log_context
 
@@ -102,6 +102,10 @@ class StorageProvider[T]:
         model: str | None = None,
         response_time: float | None = None,
         forwarded_from: list[str] | None = None,
+        provider_name: str | None = None,
+        provider_response_id: str | None = None,
+        parts: str | None = None,
+        finish_reason: FinishReason | None = None,
     ):
         """Log a message (if supported)."""
 
@@ -114,15 +118,6 @@ class StorageProvider[T]:
     ):
         """Log a conversation (if supported)."""
 
-    async def log_tool_call(
-        self,
-        *,
-        conversation_id: str,
-        message_id: str,
-        tool_call: ToolCallInfo,
-    ):
-        """Log a tool call (if supported)."""
-
     async def log_command(
         self,
         *,
@@ -168,6 +163,10 @@ class StorageProvider[T]:
             role=role,
             name=name,
             model=model,
+            provider_name=None,
+            provider_response_id=None,
+            parts=None,
+            finish_reason=None,
         )
 
     async def get_conversations(
@@ -304,44 +303,3 @@ class StorageProvider[T]:
     ) -> list[T]:
         """Get all messages up to and including checkpoint."""
         raise NotImplementedError
-
-    # Sync wrapper
-    def log_context_message_sync(self, **kwargs):
-        """Sync wrapper for log_context_message."""
-        self.task_manager.fire_and_forget(self.log_context_message(**kwargs))
-
-    # Sync wrappers for all async methods
-    def log_message_sync(self, **kwargs):
-        """Sync wrapper for log_message."""
-        self.task_manager.fire_and_forget(self.log_message(**kwargs))
-
-    def log_conversation_sync(self, **kwargs):
-        """Sync wrapper for log_conversation."""
-        self.task_manager.fire_and_forget(self.log_conversation(**kwargs))
-
-    def log_tool_call_sync(self, **kwargs):
-        """Sync wrapper for log_tool_call."""
-        self.task_manager.fire_and_forget(self.log_tool_call(**kwargs))
-
-    def log_command_sync(self, **kwargs):
-        """Sync wrapper for log_command."""
-        self.task_manager.fire_and_forget(self.log_command(**kwargs))
-
-    def get_commands_sync(self, **kwargs) -> list[str]:
-        """Sync wrapper for get_commands."""
-        return self.task_manager.run_task_sync(self.get_commands(**kwargs))
-
-    def filter_messages_sync(self, **kwargs) -> list[ChatMessage[str]]:
-        """Sync wrapper for filter_messages."""
-        return self.task_manager.run_task_sync(self.filter_messages(**kwargs))
-
-    def get_conversations_sync(
-        self, **kwargs
-    ) -> list[tuple[ConversationData, Sequence[ChatMessage[str]]]]:
-        return self.task_manager.run_task_sync(self.get_conversations(**kwargs))
-
-    def get_filtered_conversations_sync(self, **kwargs) -> list[ConversationData]:
-        return self.task_manager.run_task_sync(self.get_filtered_conversations(**kwargs))
-
-    def get_conversation_stats_sync(self, **kwargs) -> dict[str, dict[str, Any]]:
-        return self.task_manager.run_task_sync(self.get_conversation_stats(**kwargs))
