@@ -4,20 +4,22 @@ from __future__ import annotations
 
 from datetime import datetime
 from decimal import Decimal
-from typing import TYPE_CHECKING, Any, TypedDict, cast
+from typing import TYPE_CHECKING, TypedDict, cast
 
-from tokonomics.toko_types import TokenUsage
 from upath import UPath
 
 from llmling_agent.common_types import JsonValue, MessageRole  # noqa: TC001
 from llmling_agent.log import get_logger
 from llmling_agent.messaging.messages import ChatMessage, TokenCost
+from llmling_agent.storage import deserialize_parts
 from llmling_agent.utils.now import get_now
 from llmling_agent_storage.base import StorageProvider
 
 
 if TYPE_CHECKING:
-    from llmling_agent.tools import ToolCallInfo
+    from pydantic_ai import FinishReason
+    from tokonomics.toko_types import TokenUsage
+
     from llmling_agent_config.session import SessionQuery
     from llmling_agent_config.storage import FileStorageConfig
 
@@ -38,6 +40,10 @@ class MessageData(TypedDict):
     token_usage: TokenUsage | None
     response_time: float | None
     forwarded_from: list[str] | None
+    provider_name: str | None
+    provider_response_id: str | None
+    parts: str | None
+    finish_reason: FinishReason | None
 
 
 class ConversationData(TypedDict):
@@ -48,17 +54,6 @@ class ConversationData(TypedDict):
     start_time: str
 
 
-class ToolCallData(TypedDict):
-    """Data structure for storing tool call information."""
-
-    conversation_id: str
-    message_id: str
-    tool_name: str
-    args: dict[str, Any]
-    result: str
-    timestamp: str
-
-
 class CommandData(TypedDict):
     """Data structure for storing command information."""
 
@@ -75,7 +70,6 @@ class StorageData(TypedDict):
 
     messages: list[MessageData]
     conversations: list[ConversationData]
-    tool_calls: list[ToolCallData]
     commands: list[CommandData]
 
 
@@ -101,7 +95,6 @@ class FileProvider(StorageProvider):
         self._data: StorageData = {
             "messages": [],
             "conversations": [],
-            "tool_calls": [],
             "commands": [],
         }
         self._load()
@@ -114,7 +107,7 @@ class FileProvider(StorageProvider):
             self._data = yamling.load_file(
                 self.path,
                 self.format,  # pyright: ignore
-                verify_type=StorageData,  # type: ignore
+                verify_type=StorageData,
             )
         self._save()
 
@@ -161,6 +154,8 @@ class FileProvider(StorageProvider):
             # Convert to ChatMessage
             cost_info = None
             if msg["token_usage"]:
+                from llmling_agent.messaging.messages import TokenUsage
+
                 usage = cast(TokenUsage, msg["token_usage"])
                 cost = Decimal(msg["cost"] or 0.0)
                 cost_info = TokenCost(token_usage=usage, total_cost=cost)
@@ -170,11 +165,15 @@ class FileProvider(StorageProvider):
                 conversation_id=msg["conversation_id"],
                 role=cast(MessageRole, msg["role"]),
                 name=msg["name"],
-                model=msg["model"],
+                model_name=msg["model"],
                 cost_info=cost_info,
                 response_time=msg["response_time"],
                 forwarded_from=msg["forwarded_from"] or [],
                 timestamp=datetime.fromisoformat(msg["timestamp"]),
+                provider_name=msg["provider_name"],
+                provider_response_id=msg["provider_response_id"],
+                parts=deserialize_parts(msg["parts"]),
+                finish_reason=msg["finish_reason"],
             )
             messages.append(chat_message)
 
@@ -195,6 +194,10 @@ class FileProvider(StorageProvider):
         model: str | None = None,
         response_time: float | None = None,
         forwarded_from: list[str] | None = None,
+        provider_name: str | None = None,
+        provider_response_id: str | None = None,
+        parts: str | None = None,
+        finish_reason: FinishReason | None = None,
     ):
         """Log a new message."""
         self._data["messages"].append({
@@ -209,6 +212,10 @@ class FileProvider(StorageProvider):
             "token_usage": cost_info.token_usage.copy() if cost_info else None,
             "response_time": response_time,
             "forwarded_from": forwarded_from,
+            "provider_name": provider_name,
+            "provider_response_id": provider_response_id,
+            "parts": parts,
+            "finish_reason": finish_reason,
         })
         self._save()
 
@@ -228,25 +235,6 @@ class FileProvider(StorageProvider):
         self._data["conversations"].append(conversation)
         self._save()
 
-    async def log_tool_call(
-        self,
-        *,
-        conversation_id: str,
-        message_id: str,
-        tool_call: ToolCallInfo,
-    ):
-        """Log a tool call."""
-        call: ToolCallData = {
-            "conversation_id": conversation_id,
-            "message_id": message_id,
-            "tool_name": tool_call.tool_name,
-            "args": tool_call.args,
-            "result": str(tool_call.result),
-            "timestamp": tool_call.timestamp.isoformat(),
-        }
-        self._data["tool_calls"].append(call)
-        self._save()
-
     async def log_command(
         self,
         *,
@@ -306,7 +294,6 @@ class FileProvider(StorageProvider):
             self._data = {
                 "messages": [],
                 "conversations": [],
-                "tool_calls": [],
                 "commands": [],
             }
             self._save()
@@ -331,7 +318,6 @@ class FileProvider(StorageProvider):
             # Clear all
             self._data["messages"].clear()
             self._data["conversations"].clear()
-            self._data["tool_calls"].clear()
             self._data["commands"].clear()
 
         self._save()
