@@ -15,13 +15,15 @@ from llmling_agent_storage.base import StorageProvider
 
 
 if TYPE_CHECKING:
-    from llmling_agent.tools import ToolCallInfo
     from llmling_agent_config.session import SessionQuery
     from llmling_agent_config.storage import Mem0Config
 
 logger = get_logger(__name__)
 
 
+# https://docs.mem0.ai/api-reference/memory/add-memories
+
+
 class Mem0StorageProvider(StorageProvider):
     """Storage provider using mem0 for conversation history."""
 
@@ -53,6 +55,8 @@ class Mem0StorageProvider(StorageProvider):
 
     def _from_mem0_message(self, msg: dict[str, Any]) -> ChatMessage[str]:
         """Convert from mem0 message format."""
+        from llmling_agent.storage import deserialize_parts
+
         metadata = msg.get("metadata", {})
         ts = datetime.fromisoformat(metadata.get("timestamp", get_now().isoformat()))
         return ChatMessage(
@@ -61,6 +65,10 @@ class Mem0StorageProvider(StorageProvider):
             name=metadata.get("name"),
             timestamp=ts,
             metadata=metadata,
+            provider_name=metadata.get("provider_name"),
+            provider_response_id=metadata.get("provider_response_id"),
+            parts=deserialize_parts(metadata.get("parts")),
+            finish_reason=metadata.get("finish_reason"),
         )
 
     async def log_message(
@@ -74,6 +82,10 @@ class Mem0StorageProvider(StorageProvider):
         model: str | None = None,
         response_time: float | None = None,
         forwarded_from: list[str] | None = None,
+        provider_name: str | None = None,
+        provider_response_id: str | None = None,
+        parts: str | None = None,
+        finish_reason: str | None = None,
     ):
         """Log a message to mem0."""
         metadata = {
@@ -81,6 +93,10 @@ class Mem0StorageProvider(StorageProvider):
             "response_time": response_time,
             "forwarded_from": forwarded_from,
             "message_id": message_id,
+            "provider_name": provider_name,
+            "provider_response_id": provider_response_id,
+            "parts": parts,
+            "finish_reason": finish_reason,
         }
         if cost_info:
             total = float(cost_info.total_cost)
@@ -108,27 +124,6 @@ class Mem0StorageProvider(StorageProvider):
         fmt = self.config.output_format
         await self.client.add([message], user_id=conversation_id, output_format=fmt)
 
-    async def log_tool_call(
-        self,
-        conversation_id: str,
-        message_id: str,
-        tool_call: ToolCallInfo,
-    ):
-        """Log tool usage."""
-        metadata = {
-            "type": "tool_call",
-            "tool_name": tool_call.tool_name,
-            "args": tool_call.args,
-            "result": tool_call.result,
-            "error": tool_call.error,
-            "timing": tool_call.timing,
-            "message_id": message_id,
-        }
-        content = f"Tool call: {tool_call.tool_name}"
-        message = self._to_mem0_message(content=content, role="system", metadata=metadata)
-        fmt = self.config.output_format
-        await self.client.add([message], user_id=conversation_id, output_format=fmt)
-
     async def filter_messages(
         self,
         query: SessionQuery,
@@ -156,9 +151,9 @@ class Mem0StorageProvider(StorageProvider):
         # Use v2 search with filters
         text = query.contains or ""
         fmt = self.config.output_format
-        results = await self.client.search(text, "v2", filters=filters, output_format=fmt)
+        results = await self.client.search(text, filters=filters, output_format=fmt)
         # Convert to ChatMessage format
-        messages = [self._from_mem0_message(msg) for msg in results]
+        messages = [self._from_mem0_message(msg) for msg in results.values()]
 
         # Apply limit if specified
         if query.limit:
