@@ -6,6 +6,7 @@ from datetime import datetime
 from typing import TYPE_CHECKING, Any, cast
 
 from llmling_agent.messaging.messages import ChatMessage, TokenCost
+from llmling_agent.storage import deserialize_parts
 from llmling_agent.utils.now import get_now
 from llmling_agent_storage.base import StorageProvider
 from llmling_agent_storage.models import ConversationData
@@ -17,7 +18,6 @@ if TYPE_CHECKING:
     from tokonomics.toko_types import TokenUsage
 
     from llmling_agent.common_types import JsonValue
-    from llmling_agent.tools import ToolCallInfo
     from llmling_agent_config.session import SessionQuery
     from llmling_agent_config.storage import MemoryStorageConfig
     from llmling_agent_storage.models import MessageData, QueryFilters, StatsFilters
@@ -32,14 +32,12 @@ class MemoryStorageProvider(StorageProvider):
         super().__init__(config)
         self.messages: list[dict] = []
         self.conversations: list[dict] = []
-        self.tool_calls: list[dict] = []
         self.commands: list[dict] = []
 
     def cleanup(self):
         """Clear all stored data."""
         self.messages.clear()
         self.conversations.clear()
-        self.tool_calls.clear()
         self.commands.clear()
 
     async def filter_messages(self, query: SessionQuery) -> list[ChatMessage[str]]:
@@ -91,11 +89,15 @@ class MemoryStorageProvider(StorageProvider):
                 content=msg["content"],
                 role=msg["role"],
                 name=msg["name"],
-                model=msg["model"],
+                model_name=msg["model"],
                 cost_info=cost_info,
                 response_time=msg["response_time"],
                 forwarded_from=msg["forwarded_from"] or [],
                 timestamp=msg["timestamp"],
+                provider_name=msg["provider_name"],
+                provider_response_id=msg["provider_response_id"],
+                parts=deserialize_parts(msg["parts"]),
+                finish_reason=msg["finish_reason"],
             )
             filtered.append(chat_message)
 
@@ -117,8 +119,16 @@ class MemoryStorageProvider(StorageProvider):
         model: str | None = None,
         response_time: float | None = None,
         forwarded_from: list[str] | None = None,
+        provider_name: str | None = None,
+        provider_response_id: str | None = None,
+        parts: str | None = None,
+        finish_reason: str | None = None,
     ):
         """Store message in memory."""
+        if next((i for i in self.messages if i["message_id"] == message_id), None):
+            msg = f"Duplicate message ID: {message_id}"
+            raise ValueError(msg)
+
         self.messages.append({
             "conversation_id": conversation_id,
             "message_id": message_id,
@@ -129,6 +139,10 @@ class MemoryStorageProvider(StorageProvider):
             "model": model,
             "response_time": response_time,
             "forwarded_from": forwarded_from,
+            "provider_name": provider_name,
+            "provider_response_id": provider_response_id,
+            "parts": parts,
+            "finish_reason": finish_reason,
             "timestamp": get_now(),
         })
 
@@ -140,29 +154,17 @@ class MemoryStorageProvider(StorageProvider):
         start_time: datetime | None = None,
     ):
         """Store conversation in memory."""
+        if next(
+            (i for i in self.messages if i["conversation_id"] == conversation_id), None
+        ):
+            msg = f"Duplicate conversation ID: {conversation_id}"
+            raise ValueError(msg)
         self.conversations.append({
             "id": conversation_id,
             "agent_name": node_name,
             "start_time": start_time or get_now(),
         })
 
-    async def log_tool_call(
-        self,
-        *,
-        conversation_id: str,
-        message_id: str,
-        tool_call: ToolCallInfo,
-    ):
-        """Store tool call in memory."""
-        self.tool_calls.append({
-            "conversation_id": conversation_id,
-            "message_id": message_id,
-            "tool_name": tool_call.tool_name,
-            "args": tool_call.args,
-            "result": tool_call.result,
-            "timestamp": tool_call.timestamp,
-        })
-
     async def log_command(
         self,
         *,
@@ -238,7 +240,7 @@ class MemoryStorageProvider(StorageProvider):
                     content=msg["content"],
                     role=msg["role"],
                     name=msg["name"],
-                    model=msg["model"],
+                    model_name=msg["model"],
                     cost_info=cost_info,
                     response_time=msg["response_time"],
                     forwarded_from=msg["forwarded_from"],
@@ -258,7 +260,7 @@ class MemoryStorageProvider(StorageProvider):
                         "role": msg.role,
                         "content": msg.content,
                         "timestamp": msg.timestamp.isoformat(),
-                        "model": msg.model,
+                        "model": msg.model_name,
                         "name": msg.name,
                         "token_usage": msg.cost_info.token_usage
                         if msg.cost_info
@@ -354,7 +356,6 @@ class MemoryStorageProvider(StorageProvider):
             # Clear all
             self.messages.clear()
             self.conversations.clear()
-            self.tool_calls.clear()
             self.commands.clear()
 
         return conv_count, msg_count
