@@ -6,7 +6,6 @@ from llmling_agent_storage.sql_provider.sql_provider import SQLModelProvider
 from llmling_agent_storage.sql_provider.models import (
     Conversation,
     Message,
-    ToolCall,
     CommandHistory,
     MessageLog,
     ConversationLog,
@@ -19,5 +18,4 @@ __all__ = [
     "Message",
     "MessageLog",
     "SQLModelProvider",
-    "ToolCall",
 ]
