@@ -11,6 +11,7 @@ from sqlalchemy.sql import expression
 from sqlmodel import select
 
 from llmling_agent.messaging.messages import ChatMessage, TokenCost
+from llmling_agent.storage import deserialize_parts
 from llmling_agent_storage.models import ConversationData
 from llmling_agent_storage.sql_provider.models import Conversation
 
@@ -63,11 +64,15 @@ def to_chat_message(db_message: Message) -> ChatMessage[str]:
         content=db_message.content,
         role=db_message.role,  # type: ignore
         name=db_message.name,
-        model=db_message.model,
+        model_name=db_message.model,
         cost_info=cost_info,
         response_time=db_message.response_time,
         forwarded_from=db_message.forwarded_from or [],
         timestamp=db_message.timestamp,
+        provider_name=db_message.provider_name,
+        provider_response_id=db_message.provider_response_id,
+        parts=deserialize_parts(db_message.parts),
+        finish_reason=db_message.finish_reason,  # type: ignore
     )
 
 
@@ -193,7 +198,7 @@ def format_conversation(
                 "role": msg.role,
                 "content": msg.content,
                 "timestamp": msg.timestamp.isoformat(),
-                "model": msg.model,
+                "model": msg.model_name,
                 "name": msg.name,
                 "token_usage": msg.cost_info.token_usage if msg.cost_info else None,
                 "cost": float(msg.cost_info.total_cost) if msg.cost_info else None,
