@@ -16,9 +16,9 @@ if TYPE_CHECKING:
     from datetime import datetime
 
     from jinja2 import Template
+    from upath.types import JoinablePathLike
 
-    from llmling_agent.common_types import JsonValue, StrPath
-    from llmling_agent.tools import ToolCallInfo
+    from llmling_agent.common_types import JsonValue
     from llmling_agent_config.storage import LogFormat, TextLogConfig
 
 
@@ -137,7 +137,7 @@ class TextLogProvider(StorageProvider):
 
     def _load_template(
         self,
-        template: LogFormat | StrPath | None,
+        template: LogFormat | JoinablePathLike | None,
     ) -> Template:
         """Load template from predefined or file."""
         from jinja2 import Template
@@ -195,6 +195,10 @@ class TextLogProvider(StorageProvider):
         model: str | None = None,
         response_time: float | None = None,
         forwarded_from: list[str] | None = None,
+        provider_name: str | None = None,
+        provider_response_id: str | None = None,
+        parts: str | None = None,
+        finish_reason: str | None = None,
     ):
         """Store message and update log."""
         entry = {
@@ -209,6 +213,10 @@ class TextLogProvider(StorageProvider):
             "cost_info": cost_info,
             "response_time": response_time,
             "forwarded_from": forwarded_from,
+            "provider_name": provider_name,
+            "provider_response_id": provider_response_id,
+            "parts": parts,
+            "finish_reason": finish_reason,
         }
         self._entries.append(entry)
 
@@ -234,28 +242,6 @@ class TextLogProvider(StorageProvider):
         path = await self._get_path("conversation", **entry)
         self._write(path)
 
-    async def log_tool_call(
-        self,
-        *,
-        conversation_id: str,
-        message_id: str,
-        tool_call: ToolCallInfo,
-    ):
-        """Store tool call."""
-        entry = {
-            "type": "tool_call",
-            "timestamp": tool_call.timestamp,
-            "conversation_id": conversation_id,
-            "message_id": message_id,
-            "tool_name": tool_call.tool_name,
-            "args": tool_call.args,
-            "result": tool_call.result,
-        }
-        self._entries.append(entry)
-
-        path = await self._get_path("tool_call", **entry)
-        self._write(path)
-
     async def log_command(
         self,
         *,
