@@ -1,11 +1,19 @@
 """Typing-widget. Credits to Elia (https://github.com/darrenburns/elia)."""
 
-from textual.app import ComposeResult
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 from textual.containers import Vertical
-from textual.reactive import Reactive, reactive
+from textual.reactive import reactive
 from textual.widgets import Label, LoadingIndicator
 
 
+if TYPE_CHECKING:
+    from textual.app import ComposeResult
+    from textual.reactive import Reactive
+
+
 class ResponseStatus(Vertical):
     """A widget that displays the status of the response from the node."""
 
@@ -24,3 +32,9 @@ class ResponseStatus(Vertical):
         self.message = "Agent is responding"
         self.add_class("-agent-responding")
         self.remove_class("-awaiting-response")
+
+
+if __name__ == "__main__":
+    from textualicious import show
+
+    show(ResponseStatus())
